<?php
require_once __DIR__ . "/../models/AgenciaModel.php";

class AgenciaController {
    private $model;

    public function __construct($pdo) {
        $this->model = new AgenciaModel($pdo);
    }

    // Listar todas las agencias
    public function listarAgencias() {
        return $this->model->obtenerAgencias();
    }

    // Agregar una nueva agencia
    public function agregarAgencia() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["agregar_agencia"])) {
            $nombre = trim($_POST["nombreAgencia"]);
            $fax = trim($_POST["fax"]) ?: null;
            $fechaInicialCredito = trim($_POST["fechaInicialCredito"]) ?: null;
            $fechaFinalCredito = trim($_POST["fechaFinalCredito"]) ?: null;
            $precio = isset($_POST["precio"]) ? floatval($_POST["precio"]) : null;

            // Validaciones
            if (empty($nombre)) {
                header("Location: agenciacreate.php?error=El nombre de la agencia no puede estar vacío.");
                exit();
            }

            if (empty($fax)) {
                header("Location: agenciacreate.php?error=El fax no puede estar vacío.");
                exit();
            }

            if (empty($fechaInicialCredito)) {
                header("Location: agenciacreate.php?error=La fecha inicial de crédito es obligatoria.");
                exit();
            }

            if (empty($fechaFinalCredito)) {
                header("Location: agenciacreate.php?error=La fecha final de crédito es obligatoria.");
                exit();
            }

            if ($precio !== null && $precio < 0) {
                header("Location: agenciacreate.php?error=El precio no puede ser negativo.");
                exit();
            }

            // Validar formato de fechas (YYYY-MM-DD)
            $dateInicial = DateTime::createFromFormat('Y-m-d', $fechaInicialCredito);
            $dateFinal = DateTime::createFromFormat('Y-m-d', $fechaFinalCredito);
            if (!$dateInicial || $dateInicial->format('Y-m-d') !== $fechaInicialCredito) {
                header("Location: agenciacreate.php?error=La fecha inicial de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }
            if (!$dateFinal || $dateFinal->format('Y-m-d') !== $fechaFinalCredito) {
                header("Location: agenciacreate.php?error=La fecha final de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Verificar si la agencia ya existe
            $agenciasExistentes = $this->model->obtenerAgencias();
            foreach ($agenciasExistentes as $agencia) {
                if (strtolower($agencia["nombreAgencia"]) === strtolower($nombre)) {
                    header("Location: agenciacreate.php?error=La agencia ya existe.");
                    exit();
                }
            }

            // Llamar al modelo para agregar la agencia
            if ($this->model->agregarAgencia($nombre, $fax, $fechaInicialCredito, $fechaFinalCredito, $precio)) {
                header("Location: agenciacreate.php?success=Agencia agregada correctamente.");
                exit();
            } else {
                header("Location: agenciacreate.php?error=No se pudo agregar la agencia.");
                exit();
            }
        }
    }

    // Editar una agencia
    public function editarAgencia() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_agencia"])) {
            $id_agencia = intval($_POST["id_agencia"]);
            $nombre = trim($_POST["nombreAgencia"]);
            $fax = trim($_POST["fax"]) ?: null;
            $fechaInicialCredito = trim($_POST["fechaInicialCredito"]) ?: null;
            $fechaFinalCredito = trim($_POST["fechaFinalCredito"]) ?: null;
            $precio = isset($_POST["precio"]) ? floatval($_POST["precio"]) : null;

            // Validaciones
            if (empty($nombre)) {
                header("Location: agenciacreate.php?error=El nombre no puede estar vacío.");
                exit();
            }

            if (empty($fax)) {
                header("Location: agenciacreate.php?error=El fax no puede estar vacío.");
                exit();
            }

            if (empty($fechaInicialCredito)) {
                header("Location: agenciacreate.php?error=La fecha inicial de crédito es obligatoria.");
                exit();
            }

            if (empty($fechaFinalCredito)) {
                header("Location: agenciacreate.php?error=La fecha final de crédito es obligatoria.");
                exit();
            }

            if ($precio !== null && $precio < 0) {
                header("Location: agenciacreate.php?error=El precio no puede ser negativo.");
                exit();
            }

            // Validar formato de fechas (YYYY-MM-DD)
            $dateInicial = DateTime::createFromFormat('Y-m-d', $fechaInicialCredito);
            $dateFinal = DateTime::createFromFormat('Y-m-d', $fechaFinalCredito);
            if (!$dateInicial || $dateInicial->format('Y-m-d') !== $fechaInicialCredito) {
                header("Location: agenciacreate.php?error=La fecha inicial de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }
            if (!$dateFinal || $dateFinal->format('Y-m-d') !== $fechaFinalCredito) {
                header("Location: agenciacreate.php?error=La fecha final de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Llamar al modelo para editar la agencia
            if ($this->model->editarAgencia($id_agencia, $nombre, $fax, $fechaInicialCredito, $fechaFinalCredito, $precio)) {
                header("Location: agenciacreate.php?success=Agencia actualizada correctamente.");
                exit();
            } else {
                header("Location: agenciacreate.php?error=No se pudo actualizar la agencia.");
                exit();
            }
        }
    }

    // Eliminar una agencia
    public function eliminarAgencia() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["eliminar_agencia"])) {
            $id_agencia = intval($_POST["id_agencia"]);

            if ($this->model->eliminarAgencia($id_agencia)) {
                header("Location: agenciacreate.php?success=Agencia eliminada correctamente.");
                exit();
            } else {
                header("Location: agenciacreate.php?error=No se pudo eliminar la agencia.");
                exit();
            }
        }
    }
}