<?php
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../models/CajaChicaModel.php';

class CajaChicaController {
    private $model;

    public function __construct($pdo) {
        $this->model = new CajaChicaModel($pdo);
    }

    // Listar movimientos de caja chica y productos vendidos para una fecha específica
    public function listarMovimientos($fecha) {
        $movimientos = $this->model->getMovimientos($fecha);
        $productos_vendidos = $this->model->getProductosVendidos($fecha);
        $caja_diaria = $this->model->getCajaDiaria($fecha);

        $monto_apertura = $caja_diaria['monto_apertura'] ?? 0.00;
        $monto_final = $caja_diaria['monto_final'] ?? 0.00;

        $ingresos_caja = 0;
        $egresos_caja = 0;
        foreach ($movimientos as $movimiento) {
            if ($movimiento['tipo_movimiento'] === 'ingreso') {
                $ingresos_caja += $movimiento['monto'];
            } else {
                $egresos_caja += $movimiento['monto'];
            }
        }

        $ingresos_productos = 0;
        foreach ($productos_vendidos as $producto) {
            $ingresos_productos += $producto['costo_total'];
        }

        $total_ingresos = $ingresos_caja + $ingresos_productos;
        $saldo = $monto_apertura + $total_ingresos - $egresos_caja;

        return [
            'movimientos' => $movimientos,
            'productos_vendidos' => $productos_vendidos,
            'monto_apertura' => $monto_apertura,
            'monto_final' => $monto_final,
            'ingresos_caja' => $ingresos_caja,
            'ingresos_productos' => $ingresos_productos,
            'total_ingresos' => $total_ingresos,
            'egresos_caja' => $egresos_caja,
            'saldo' => $saldo,
            'fecha' => $fecha
        ];
    }

    // Registrar un nuevo movimiento (ingreso o egreso)
    public function registrarMovimiento() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['registrar_movimiento'])) {
            $tipo_movimiento = $_POST['tipo_movimiento'];
            $descripcion = $_POST['descripcion'];
            $monto = $_POST['monto'];
            $fecha = $_POST['fecha'];
            $usuario_id = isset($_SESSION['usuario_id']) ? $_SESSION['usuario_id'] : null;

            if (empty($tipo_movimiento) || empty($descripcion) || empty($monto) || empty($fecha)) {
                header("Location: ListadoCajaChica.php?fecha=$fecha&error=All fields are required.");
                exit();
            }

            if (!is_numeric($monto) || $monto <= 0) {
                header("Location: ListadoCajaChica.php?fecha=$fecha&error=Invalid amount.");
                exit();
            }

            $this->model->registrarMovimiento($tipo_movimiento, $descripcion, $monto, $fecha, $usuario_id);
            header("Location: ListadoCajaChica.php?fecha=$fecha&success=Movement registered successfully.");
            exit();
        }
    }

    // Registrar el monto de apertura
    public function registrarMontoApertura() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['registrar_apertura'])) {
            $fecha = $_POST['fecha'];
            $monto_apertura = $_POST['monto_apertura'];
            $usuario_id = isset($_SESSION['usuario_id']) ? $_SESSION['usuario_id'] : null;

            if (!is_numeric($monto_apertura) || $monto_apertura < 0) {
                header("Location: ListadoCajaChica.php?fecha=$fecha&error=Invalid opening amount.");
                exit();
            }

            $this->model->registrarMontoApertura($fecha, $monto_apertura, $usuario_id);
            header("Location: ListadoCajaChica.php?fecha=$fecha&success=Opening amount registered successfully.");
            exit();
        }
    }

    // Registrar el monto final
    public function registrarMontoFinal() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['registrar_cierre'])) {
            $fecha = $_POST['fecha'];
            $monto_final = $_POST['monto_final'];
            $usuario_id = isset($_SESSION['usuario_id']) ? $_SESSION['usuario_id'] : null;

            if (!is_numeric($monto_final) || $monto_final < 0) {
                header("Location: ListadoCajaChica.php?fecha=$fecha&error=Invalid closing amount.");
                exit();
            }

            $this->model->registrarMontoFinal($fecha, $monto_final, $usuario_id);
            header("Location: ListadoCajaChica.php?fecha=$fecha&success=Closing amount registered successfully.");
            exit();
        }
    }
}