<?php
require_once __DIR__ . "/../models/GuiaModel.php";

class GuiaController {
    private $model;

    public function __construct($pdo) {
        $this->model = new GuiaModel($pdo);
    }

    // Listar todos los guías
    public function listarGuias() {
        return $this->model->obtenerGuias();
    }

    // Agregar un nuevo guía
    public function agregarGuia() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["agregar_guia"])) {
            $nombre = trim($_POST["nombreGuia"]);
            $tipo_documento = trim($_POST["tipo_documento"]);
            $inicio_credito = $_POST["inicio_credito"];
            $celular = trim($_POST["celular"]);

            // Validaciones
            if (empty($nombre)) {
                header("Location: guiacreate.php?error=El nombre del guía no puede estar vacío.");
                exit();
            }

            if (empty($tipo_documento)) {
                header("Location: guiacreate.php?error=El tipo de documento no puede estar vacío.");
                exit();
            }

            if (empty($inicio_credito)) {
                header("Location: guiacreate.php?error=La fecha de inicio de crédito no puede estar vacía.");
                exit();
            }

            if (empty($celular)) {
                header("Location: guiacreate.php?error=El número de celular no puede estar vacío.");
                exit();
            }

            // Validar formato de celular (ejemplo: +51 987654321)
            if (!preg_match('/^\+\d{1,3}\s\d{9}$/', $celular)) {
                header("Location: guiacreate.php?error=El formato del celular debe ser como +51 987654321.");
                exit();
            }

            // Validar tipo_documento (solo RCU o DNI)
            if (!in_array(strtoupper($tipo_documento), ['RCU', 'DNI'])) {
                header("Location: guiacreate.php?error=El tipo de documento debe ser RCU o DNI.");
                exit();
            }

            // Validar formato de fecha (YYYY-MM-DD)
            $date = DateTime::createFromFormat('Y-m-d', $inicio_credito);
            if (!$date || $date->format('Y-m-d') !== $inicio_credito) {
                header("Location: guiacreate.php?error=La fecha de inicio de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Verificar si el guía ya existe
            $guiasExistentes = $this->model->obtenerGuias();
            foreach ($guiasExistentes as $guia) {
                if (strtolower($guia["nombreGuia"]) === strtolower($nombre)) {
                    header("Location: guiacreate.php?error=El guía ya existe.");
                    exit();
                }
            }

            // Llamar al modelo para agregar el guía
            if ($this->model->agregarGuia($nombre, $tipo_documento, $inicio_credito, $celular)) {
                header("Location: guialist.php?success=Guía agregado correctamente.");
                exit();
            } else {
                header("Location: guiacreate.php?error=No se pudo agregar el guía.");
                exit();
            }
        }
    }

    // Editar un guía
    public function editarGuia() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_guia"])) {
            $id_guia = intval($_POST["id_guia"]);
            $nombre = trim($_POST["nombreGuia"]);
            $tipo_documento = trim($_POST["tipo_documento"]);
            $inicio_credito = $_POST["inicio_credito"];
            $celular = trim($_POST["celular"]);

            // Validaciones
            if (empty($nombre)) {
                header("Location: guiaedit.php?id=$id_guia&error=El nombre no puede estar vacío.");
                exit();
            }

            if (empty($tipo_documento)) {
                header("Location: guiaedit.php?id=$id_guia&error=El tipo de documento no puede estar vacío.");
                exit();
            }

            if (empty($inicio_credito)) {
                header("Location: guiaedit.php?id=$id_guia&error=La fecha de inicio de crédito no puede estar vacía.");
                exit();
            }

            if (empty($celular)) {
                header("Location: guiaedit.php?id=$id_guia&error=El número de celular no puede estar vacío.");
                exit();
            }

            // Validar formato de celular (ejemplo: +51 987654321)
            if (!preg_match('/^\+\d{1,3}\s\d{9}$/', $celular)) {
                header("Location: guiaedit.php?id=$id_guia&error=El formato del celular debe ser como +51 987654321.");
                exit();
            }

            // Validar tipo_documento (solo RCU o DNI)
            if (!in_array(strtoupper($tipo_documento), ['RCU', 'DNI'])) {
                header("Location: guiaedit.php?id=$id_guia&error=El tipo de documento debe ser RCU o DNI.");
                exit();
            }

            // Validar formato de fecha (YYYY-MM-DD)
            $date = DateTime::createFromFormat('Y-m-d', $inicio_credito);
            if (!$date || $date->format('Y-m-d') !== $inicio_credito) {
                header("Location: guiaedit.php?id=$id_guia&error=La fecha de inicio de crédito debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Llamar al modelo para editar el guía
            if ($this->model->editarGuia($id_guia, $nombre, $tipo_documento, $inicio_credito, $celular)) {
                header("Location: guialist.php?success=Guía actualizado correctamente.");
                exit();
            } else {
                header("Location: guiaedit.php?id=$id_guia&error=No se pudo actualizar el guía.");
                exit();
            }
        }
    }

    // Eliminar un guía
    public function eliminarGuia() {
        if (isset($_GET["id"])) {
            $id_guia = intval($_GET["id"]);

            if ($this->model->eliminarGuia($id_guia)) {
                header("Location: guialist.php?success=Guía eliminado correctamente.");
                exit();
            } else {
                header("Location: guialist.php?error=No se pudo eliminar el guía.");
                exit();
            }
        }
    }
}