<?php
require_once __DIR__ . "/../models/UserModel.php";

class LoginController {
    private $userModel;

    public function __construct($pdo) {
        $this->userModel = new UserModel($pdo);
    }

    // Mostrar el formulario de login
    public function showLoginForm() {
        if (isset($_SESSION['user_id'])) {
            header("Location: reserva/reservalist.php");
            exit();
        }
    }

    // Procesar el login
    public function login() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["login"])) {
            $username = trim($_POST["username"]);
            $password = trim($_POST["password"]);

            // Depuración: Verificar los datos recibidos
            error_log("Datos recibidos en login: username=$username, password=$password");

            // Validaciones
            if (empty($username) || empty($password)) {
                error_log("Error: El nombre de usuario y la contraseña son obligatorios.");
                header("Location: login.php?error=El nombre de usuario y la contraseña son obligatorios.");
                exit();
            }

            // Obtener el usuario
            $user = $this->userModel->getUserByUsername($username);
            if ($user) {
                error_log("Usuario encontrado: " . print_r($user, true));
                // Verificar la contraseña
                if (password_verify($password, $user['password'])) {
                    error_log("Éxito: Contraseña verificada correctamente.");
                    // Iniciar sesión
                    session_start();
                    $_SESSION['user_id'] = $user['id_usuario'];
                    $_SESSION['username'] = $user['username'];
                    header("Location: principal.php"); // Corregir la redirección
                    exit();
                } else {
                    error_log("Error: Contraseña incorrecta para el usuario $username.");
                    header("Location: login.php?error=Nombre de usuario o contraseña incorrectos.");
                    exit();
                }
            } else {
                error_log("Error: No se encontró un usuario con el nombre $username.");
                header("Location: login.php?error=Nombre de usuario o contraseña incorrectos.");
                exit();
            }
        }
    }

    // Cerrar sesión
    public function logout() {
        session_start();
        session_unset();
        session_destroy();
        header("Location: login.php?success=Sesión cerrada correctamente.");
        exit();
    }
}