<?php
require_once __DIR__ . "/../models/MesaModel.php";

class MesaController {
    private $model;

    public function __construct($pdo) {
        $this->model = new MesaModel($pdo);
    }

    // Generar y listar mesas para un día
    public function listarMesas($fecha = null) {
        if (!$fecha) {
            $fecha = date('Y-m-d'); // Fecha actual por defecto (17 de abril de 2025)
        }
        // Validar formato de fecha
        $date = DateTime::createFromFormat('Y-m-d', $fecha);
        if (!$date || $date->format('Y-m-d') !== $fecha) {
            header("Location: GestionMesas.php?error=Fecha inválida.");
            exit();
        }

        // Generar mesas para la fecha si no existen
        $this->model->generarMesas($fecha);

        // Obtener mesas
        $mesas = $this->model->obtenerMesas($fecha);

        // Obtener productos para cada mesa
        foreach ($mesas as &$mesa) {
            $mesa['productos'] = $this->model->obtenerProductosMesa($mesa['id_mesa']);
        }

        // Obtener lista de productos disponibles
        $productos = $this->model->obtenerProductos();

        return [
            'mesas' => $mesas,
            'fecha' => $fecha,
            'productos' => $productos
        ];
    }

    // Actualizar estado de una mesa
    public function actualizarEstadoMesa() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["actualizar_estado_mesa"])) {
            $id_mesa = intval($_POST["id_mesa"]);
            $estado_atencion = trim($_POST["estado_atencion"]);
            $fecha = trim($_POST["fecha"]); // Para redirigir a la misma fecha

            if ($id_mesa <= 0) {
                header("Location: GestionMesas.php?fecha=$fecha&error=ID de mesa inválido.");
                exit();
            }

            if ($this->model->actualizarEstadoMesa($id_mesa, $estado_atencion)) {
                header("Location: GestionMesas.php?fecha=$fecha&success=Estado actualizado correctamente.");
                exit();
            } else {
                header("Location: GestionMesas.php?fecha=$fecha&error=No se pudo actualizar el estado.");
                exit();
            }
        }
    }

    // Agregar producto a una mesa
    public function agregarProductoMesa() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["agregar_producto_mesa"])) {
            $id_mesa = intval($_POST["id_mesa"]);
            $id_producto = intval($_POST["id_producto"]);
            $cantidad = intval($_POST["cantidad"]);
            $fecha = trim($_POST["fecha"]); // Para redirigir

            if ($id_mesa <= 0 || $id_producto <= 0 || $cantidad <= 0) {
                header("Location: GestionMesas.php?fecha=$fecha&error=Datos inválidos para agregar producto.");
                exit();
            }

            if ($this->model->agregarProductoMesa($id_mesa, $id_producto, $cantidad)) {
                header("Location: GestionMesas.php?fecha=$fecha&success=Producto agregado correctamente.");
                exit();
            } else {
                header("Location: GestionMesas.php?fecha=$fecha&error=No se pudo agregar el producto.");
                exit();
            }
        }
    }

    // Actualizar estado de pago de un producto
    public function actualizarEstadoPagoProducto() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["actualizar_estado_pago"])) {
            $id_mesa_producto = intval($_POST["id_mesa_producto"]);
            $estado_pago = trim($_POST["estado_pago"]);
            $check_verificado = isset($_POST["check_verificado"]) ? 1 : 0;
            $fecha = trim($_POST["fecha"]); // Para redirigir

            if ($id_mesa_producto <= 0) {
                header("Location: GestionMesas.php?fecha=$fecha&error=ID de producto inválido.");
                exit();
            }

            if ($this->model->actualizarEstadoPagoProducto($id_mesa_producto, $estado_pago, $check_verificado)) {
                header("Location: GestionMesas.php?fecha=$fecha&success=Estado de pago actualizado correctamente.");
                exit();
            } else {
                header("Location: GestionMesas.php?fecha=$fecha&error=No se pudo actualizar el estado de pago.");
                exit();
            }
        }
    }
}