<?php
require_once __DIR__ . "/../models/ProductoModel.php";

class ProductoController {
    private $model;

    public function __construct($pdo) {
        $this->model = new ProductoModel($pdo);
    }

    // Listar todos los productos
    public function listarProductos() {
        return $this->model->obtenerProductos();
    }

    // Agregar un nuevo producto
    public function agregarProducto() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["agregar_producto"])) {
            $nombre = trim($_POST["nombreProdu"]);
            $cantidad = intval($_POST["cantidad"]);
            $fecha_pedido = trim($_POST["fecha_pedido"]);
            $unidad = trim($_POST["unidad"]);
            $precio_abarrote = floatval($_POST["precio_abarrote"]);
            $precio_mercado = floatval($_POST["precio_mercado"]);
            $precio_referencial = floatval($_POST["precio_referencial"]);
            $categoria = trim($_POST["categoria"]);

            // Validaciones
            if (empty($nombre)) {
                header("Location: productocreate.php?error=El nombre del producto no puede estar vacío.");
                exit();
            }

            if ($cantidad <= 0) {
                header("Location: productocreate.php?error=La cantidad debe ser mayor que 0.");
                exit();
            }

            if (empty($fecha_pedido)) {
                header("Location: productocreate.php?error=La fecha de pedido es obligatoria.");
                exit();
            }

            if (empty($unidad)) {
                header("Location: productocreate.php?error=La unidad no puede estar vacía.");
                exit();
            }

            if ($precio_abarrote < 0) {
                header("Location: productocreate.php?error=El precio de abarrote no puede ser negativo.");
                exit();
            }

            if ($precio_mercado < 0) {
                header("Location: productocreate.php?error=El precio de mercado no puede ser negativo.");
                exit();
            }

            if ($precio_referencial < 0) {
                header("Location: productocreate.php?error=El precio referencial no puede ser negativo.");
                exit();
            }

            if (empty($categoria)) {
                header("Location: productocreate.php?error=La categoría no puede estar vacía.");
                exit();
            }

            // Validar formato de fecha (YYYY-MM-DD)
            $date = DateTime::createFromFormat('Y-m-d', $fecha_pedido);
            if (!$date || $date->format('Y-m-d') !== $fecha_pedido) {
                header("Location: productocreate.php?error=La fecha de pedido debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Verificar si el producto ya existe
            $productosExistentes = $this->model->obtenerProductos();
            foreach ($productosExistentes as $producto) {
                if (strtolower($producto["nombreProdu"]) === strtolower($nombre)) {
                    header("Location: productocreate.php?error=El producto ya existe.");
                    exit();
                }
            }

            // Llamar al modelo para agregar el producto
            if ($this->model->agregarProducto($nombre, $cantidad, $fecha_pedido, $unidad, $precio_abarrote, $precio_mercado, $precio_referencial, $categoria)) {
                header("Location: productocreate.php?success=Producto agregado correctamente.");
                exit();
            } else {
                header("Location: productocreate.php?error=No se pudo agregar el producto.");
                exit();
            }
        }
    }

    // Editar un producto
    public function editarProducto() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_producto"])) {
            $id_productos = intval($_POST["id_productos"]);
            $nombre = trim($_POST["nombreProdu"]);
            $cantidad = intval($_POST["cantidad"]);
            $fecha_pedido = trim($_POST["fecha_pedido"]);
            $unidad = trim($_POST["unidad"]);
            $precio_abarrote = floatval($_POST["precio_abarrote"]);
            $precio_mercado = floatval($_POST["precio_mercado"]);
            $precio_referencial = floatval($_POST["precio_referencial"]);
            $categoria = trim($_POST["categoria"]);

            // Validaciones
            if (empty($nombre)) {
                header("Location: productocreate.php?error=El nombre no puede estar vacío.");
                exit();
            }

            if ($cantidad <= 0) {
                header("Location: productocreate.php?error=La cantidad debe ser mayor que 0.");
                exit();
            }

            if (empty($fecha_pedido)) {
                header("Location: productocreate.php?error=La fecha de pedido es obligatoria.");
                exit();
            }

            if (empty($unidad)) {
                header("Location: productocreate.php?error=La unidad no puede estar vacía.");
                exit();
            }

            if ($precio_abarrote < 0) {
                header("Location: productocreate.php?error=El precio de abarrote no puede ser negativo.");
                exit();
            }

            if ($precio_mercado < 0) {
                header("Location: productocreate.php?error=El precio de mercado no puede ser negativo.");
                exit();
            }

            if ($precio_referencial < 0) {
                header("Location: productocreate.php?error=El precio referencial no puede ser negativo.");
                exit();
            }

            if (empty($categoria)) {
                header("Location: productocreate.php?error=La categoría no puede estar vacía.");
                exit();
            }

            // Validar formato de fecha (YYYY-MM-DD)
            $date = DateTime::createFromFormat('Y-m-d', $fecha_pedido);
            if (!$date || $date->format('Y-m-d') !== $fecha_pedido) {
                header("Location: productocreate.php?error=La fecha de pedido debe estar en formato YYYY-MM-DD.");
                exit();
            }

            // Llamar al modelo para editar el producto
            if ($this->model->editarProducto($id_productos, $nombre, $cantidad, $fecha_pedido, $unidad, $precio_abarrote, $precio_mercado, $precio_referencial, $categoria)) {
                header("Location: productocreate.php?success=Producto actualizado correctamente.");
                exit();
            } else {
                header("Location: productocreate.php?error=No se pudo actualizar el producto.");
                exit();
            }
        }
    }

    // Eliminar un producto
    public function eliminarProducto() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["eliminar_producto"])) {
            $id_productos = intval($_POST["id_productos"]);

            if ($this->model->eliminarProducto($id_productos)) {
                header("Location: productocreate.php?success=Producto eliminado correctamente.");
                exit();
            } else {
                header("Location: productocreate.php?error=No se pudo eliminar el producto.");
                exit();
            }
        }
    }
}