<?php
require_once __DIR__ . "/../models/ReporteModel.php";

// Verificar si el archivo de la librería existe antes de incluirlo
$libPath = __DIR__ . "/../libs/xlsxwriter.class.php";

require_once $libPath;

class ReporteController {
    private $model;

    public function __construct($pdo) {
        $this->model = new ReporteModel($pdo);
    }

    // Método para obtener las listas de agencias y guías (para los filtros)
    public function obtenerFiltros() {
        return [
            'agencias' => $this->model->obtenerAgencias(),
            'guias' => $this->model->obtenerGuias()
        ];
    }

    public function generarReporte() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["generar_reporte"])) {
            $tipoReporte = trim($_POST["tipo_reporte"]);
            $fechaInicio = trim($_POST["fecha_inicio"]);
            $fechaFin = trim($_POST["fecha_fin"]);
            $id_agencia = !empty($_POST["id_agencia"]) ? trim($_POST["id_agencia"]) : null;
            $id_guia = !empty($_POST["id_guia"]) ? trim($_POST["id_guia"]) : null;

            if (empty($tipoReporte) || empty($fechaInicio) || empty($fechaFin)) {
                header("Location: ../Reporte/ListaReporte.php?error=Por favor, completa todos los campos obligatorios (tipo de reporte y fechas).");
                exit();
            }

            $inicio = DateTime::createFromFormat('Y-m-d', $fechaInicio);
            $fin = DateTime::createFromFormat('Y-m-d', $fechaFin);
            if (!$inicio || $inicio->format('Y-m-d') !== $fechaInicio || !$fin || $fin->format('Y-m-d') !== $fechaFin) {
                header("Location: ../Reporte/ListaReporte.php?error=Las fechas deben estar en formato YYYY-MM-DD.");
                exit();
            }

            if ($inicio > $fin) {
                header("Location: ../Reporte/ListaReporte.php?error=La fecha de inicio no puede ser posterior a la fecha de fin.");
                exit();
            }

            $datosReporte = [];
            if ($tipoReporte === "flujo_caja") {
                $datosReporte = $this->model->obtenerReporteFlujoCaja($fechaInicio, $fechaFin);
            } elseif ($tipoReporte === "ingresos_reservas") {
                $datosReporte = $this->model->obtenerReporteIngresosReservas($fechaInicio, $fechaFin, $id_agencia, $id_guia);
            } else {
                header("Location: ../Reporte/ListaReporte.php?error=Tipo de reporte no válido.");
                exit();
            }

            if ($datosReporte === false) {
                header("Location: ../Reporte/ListaReporte.php?error=No se pudo generar el reporte.");
                exit();
            }

            session_start();
            $_SESSION['datos_reporte'] = $datosReporte;
            $_SESSION['tipo_reporte'] = $tipoReporte;
            $_SESSION['fecha_inicio'] = $fechaInicio; // Guardar para usar en exportación
            $_SESSION['fecha_fin'] = $fechaFin; // Guardar para usar en exportación
            header("Location: ../Reporte/ListaReporte.php?success=Reporte generado correctamente.");
            exit();
        }
    }

    public function exportarExcel() {
        if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["exportar_excel"])) {
            // Iniciar la sesión para acceder a los datos
            session_start();

            // Verificar que las variables de sesión estén definidas
            if (!isset($_SESSION['datos_reporte']) || !isset($_SESSION['tipo_reporte'])) {
                header("Location: ../Reporte/ListaReporte.php?error=No hay datos para exportar. Por favor, genera un reporte primero.");
                exit();
            }

            $datosReporte = $_SESSION['datos_reporte'] ?? [];
            $tipoReporte = $_SESSION['tipo_reporte'] ?? '';

            // Verificar que los datos no estén vacíos
            if (empty($datosReporte) || empty($tipoReporte)) {
                header("Location: ../Reporte/ListaReporte.php?error=No hay datos válidos para exportar.");
                exit();
            }

            // Desactivar cualquier salida de depuración para evitar corromper el archivo
            ini_set('display_errors', 0);
            ini_set('display_startup_errors', 0);
            error_reporting(0);

            // Limpiar el búfer de salida para evitar datos adicionales
            if (ob_get_length()) {
                ob_end_clean();
            }

            $writer = new XLSXWriter();

            if ($tipoReporte === "flujo_caja") {
                $header = [
                    'Fecha' => 'string',
                    'Monto Apertura' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Monto Final' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Total Ingresos' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Total Egresos' => ['format' => '0.00', 'font-style' => 'bold']
                ];

                $writer->writeSheetHeader('FlujoCaja', $header);

                foreach ($datosReporte as $fila) {
                    $writer->writeSheetRow('FlujoCaja', [
                        $fila['fecha'],
                        floatval($fila['monto_apertura']),
                        floatval($fila['monto_final']),
                        floatval($fila['total_ingresos']),
                        floatval($fila['total_egresos'])
                    ]);
                }

                $nombreArchivo = 'Reporte_FlujoCaja_' . date('Ymd_His') . '.xlsx';

            } elseif ($tipoReporte === "ingresos_reservas") {
                $header = [
                    'Fecha' => 'string',
                    'Agencia' => 'string',
                    'Guía' => 'string',
                    'Número de Pasajeros' => 'integer',
                    'Ingresos Totales' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Adelanto' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Total' => ['format' => '0.00', 'font-style' => 'bold'],
                    'Estado' => 'string'
                ];

                $writer->writeSheetHeader('IngresosReservas', $header);

                foreach ($datosReporte as $fila) {
                    $writer->writeSheetRow('IngresosReservas', [
                        $fila['fecha_mes_y_año'],
                        $fila['nombreAgencia'],
                        $fila['nombreGuia'],
                        intval($fila['numero_pasajeros']),
                        floatval($fila['total_revenue'] ?? 0),
                        floatval($fila['adelanto']),
                        floatval($fila['totalidad']),
                        $fila['estado']
                    ]);
                }

                $nombreArchivo = 'Reporte_IngresosReservas_' . date('Ymd_His') . '.xlsx';
            } else {
                header("Location: ../Reporte/ListaReporte.php?error=Tipo de reporte no válido para exportar.");
                exit();
            }

            // Configurar las cabeceras HTTP para la descarga
            header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
            header('Content-Disposition: attachment;filename="' . $nombreArchivo . '"');
            header('Cache-Control: max-age=0');
            header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
            header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
            header('Cache-Control: cache, must-revalidate');
            header('Pragma: public');

            // Generar y descargar el archivo
            $writer->writeToStdOut();
            exit();
        }
    }
}