<?php
require_once __DIR__ . "/../config/config.php";

class AgenciaModel {
    private $pdo;

    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // Obtener todas las agencias
    public function obtenerAgencias() {
        $stmt = $this->pdo->prepare("SELECT id_agencia, nombreAgencia, fax, fechaInicialCredito, fechaFinalCredito, precio FROM agencia ORDER BY nombreAgencia ASC");
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Agregar una agencia
    public function agregarAgencia($nombre, $fax = null, $fechaInicialCredito = null, $fechaFinalCredito = null, $precio = null) {
        $stmt = $this->pdo->prepare("INSERT INTO agencia (nombreAgencia, fax, fechaInicialCredito, fechaFinalCredito, precio) VALUES (:nombre, :fax, :fechaInicialCredito, :fechaFinalCredito, :precio)");
        return $stmt->execute([
            ":nombre" => htmlspecialchars($nombre),
            ":fax" => $fax ? htmlspecialchars($fax) : null,
            ":fechaInicialCredito" => $fechaInicialCredito ?: null,
            ":fechaFinalCredito" => $fechaFinalCredito ?: null,
            ":precio" => $precio !== null ? floatval($precio) : null
        ]);
    }

    // Editar una agencia
    public function editarAgencia($id_agencia, $nombre, $fax = null, $fechaInicialCredito = null, $fechaFinalCredito = null, $precio = null) {
        $stmt = $this->pdo->prepare("UPDATE agencia SET nombreAgencia = :nombre, fax = :fax, fechaInicialCredito = :fechaInicialCredito, fechaFinalCredito = :fechaFinalCredito, precio = :precio WHERE id_agencia = :id_agencia");
        return $stmt->execute([
            ":nombre" => htmlspecialchars($nombre),
            ":fax" => $fax ? htmlspecialchars($fax) : null,
            ":fechaInicialCredito" => $fechaInicialCredito ?: null,
            ":fechaFinalCredito" => $fechaFinalCredito ?: null,
            ":precio" => $precio !== null ? floatval($precio) : null,
            ":id_agencia" => $id_agencia
        ]);
    }

    // Eliminar una agencia
    public function eliminarAgencia($id_agencia) {
        $stmt = $this->pdo->prepare("DELETE FROM agencia WHERE id_agencia = :id_agencia");
        return $stmt->execute([":id_agencia" => $id_agencia]);
    }
}