<?php
require_once __DIR__ . '/../config/config.php';

class CajaChicaModel {
    private $pdo;

    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // Obtener los movimientos de caja chica para una fecha específica
    public function getMovimientos($fecha) {
        $sql = "SELECT cc.*, u.username 
                FROM caja_chica cc 
                LEFT JOIN usuarios u ON cc.usuario_id = u.id_usuario 
                WHERE cc.fecha = :fecha 
                ORDER BY cc.hora DESC";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute(['fecha' => $fecha]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Obtener los productos vendidos (ingresos) desde mesa_productos para una fecha específica
    public function getProductosVendidos($fecha) {
        $sql = "SELECT mp.*, p.nombreProdu 
                FROM mesa_productos mp 
                JOIN productos p ON mp.id_producto = p.id_productos 
                WHERE DATE(mp.creado_en) = :fecha AND mp.estado_pago = 'pagado'";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute(['fecha' => $fecha]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Obtener el monto de apertura y cierre para una fecha específica
    public function getCajaDiaria($fecha) {
        $sql = "SELECT * FROM caja_chica_diaria WHERE fecha = :fecha";
        $stmt = $this->pdo->prepare($sql);
        $stmt->execute(['fecha' => $fecha]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }

    // Registrar un movimiento (ingreso o egreso)
    public function registrarMovimiento($tipo_movimiento, $descripcion, $monto, $fecha, $usuario_id = null) {
        $sql = "INSERT INTO caja_chica (tipo_movimiento, descripcion, monto, fecha, hora, usuario_id) 
                VALUES (:tipo_movimiento, :descripcion, :monto, :fecha, NOW(), :usuario_id)";
        $stmt = $this->pdo->prepare($sql);
        return $stmt->execute([
            'tipo_movimiento' => $tipo_movimiento,
            'descripcion' => $descripcion,
            'monto' => $monto,
            'fecha' => $fecha,
            'usuario_id' => $usuario_id
        ]);
    }

    // Registrar o actualizar el monto de apertura para una fecha
    public function registrarMontoApertura($fecha, $monto_apertura, $usuario_id = null) {
        $sql = "INSERT INTO caja_chica_diaria (fecha, monto_apertura, usuario_id) 
                VALUES (:fecha, :monto_apertura, :usuario_id) 
                ON DUPLICATE KEY UPDATE monto_apertura = :monto_apertura, usuario_id = :usuario_id";
        $stmt = $this->pdo->prepare($sql);
        return $stmt->execute([
            'fecha' => $fecha,
            'monto_apertura' => $monto_apertura,
            'usuario_id' => $usuario_id
        ]);
    }

    // Registrar o actualizar el monto final para una fecha
    public function registrarMontoFinal($fecha, $monto_final, $usuario_id = null) {
        $sql = "INSERT INTO caja_chica_diaria (fecha, monto_final, usuario_id) 
                VALUES (:fecha, :monto_final, :usuario_id) 
                ON DUPLICATE KEY UPDATE monto_final = :monto_final, usuario_id = :usuario_id";
        $stmt = $this->pdo->prepare($sql);
        return $stmt->execute([
            'fecha' => $fecha,
            'monto_final' => $monto_final,
            'usuario_id' => $usuario_id
        ]);
    }
}