<?php
require_once __DIR__ . "/../config/config.php";

class GuiaModel {
    private $pdo;

    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // Obtener todos los guías
    public function obtenerGuias() {
        $stmt = $this->pdo->prepare("SELECT id_guia, nombreGuia, tipo_documento, inicio_credito, celular FROM guia ORDER BY nombreGuia ASC");
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Agregar un guía
    public function agregarGuia($nombre, $tipo_documento, $inicio_credito, $celular) {
        $stmt = $this->pdo->prepare("INSERT INTO guia (nombreGuia, tipo_documento, inicio_credito, celular) VALUES (:nombre, :tipo_documento, :inicio_credito, :celular)");
        return $stmt->execute([
            ":nombre" => htmlspecialchars($nombre),
            ":tipo_documento" => htmlspecialchars($tipo_documento),
            ":inicio_credito" => $inicio_credito, // La fecha no necesita htmlspecialchars, pero debe estar en formato YYYY-MM-DD
            ":celular" => htmlspecialchars($celular)
        ]);
    }

    // Editar un guía
    public function editarGuia($id_guia, $nombre, $tipo_documento, $inicio_credito, $celular) {
        $stmt = $this->pdo->prepare("UPDATE guia SET nombreGuia = :nombre, tipo_documento = :tipo_documento, inicio_credito = :inicio_credito, celular = :celular WHERE id_guia = :id_guia");
        return $stmt->execute([
            ":nombre" => htmlspecialchars($nombre),
            ":tipo_documento" => htmlspecialchars($tipo_documento),
            ":inicio_credito" => $inicio_credito,
            ":celular" => htmlspecialchars($celular),
            ":id_guia" => $id_guia
        ]);
    }

    // Eliminar un guía
    public function eliminarGuia($id_guia) {
        $stmt = $this->pdo->prepare("DELETE FROM guia WHERE id_guia = :id_guia");
        return $stmt->execute([":id_guia" => $id_guia]);
    }
}