<?php
require_once __DIR__ . "/../config/config.php";

class ReporteModel {
    private $pdo;

    public function __construct($pdo) {
        $this->pdo = $pdo;
    }

    // Obtener todas las agencias para el filtro
    public function obtenerAgencias() {
        $query = "SELECT id_agencia, nombreAgencia FROM agencia ORDER BY nombreAgencia ASC";
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Obtener todos los guías para el filtro
    public function obtenerGuias() {
        $query = "SELECT id_guia, nombreGuia FROM guia ORDER BY nombreGuia ASC";
        $stmt = $this->pdo->prepare($query);
        $stmt->execute();
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Obtener el reporte de flujo de caja diario (este no se filtra por agencia ni guía)
    public function obtenerReporteFlujoCaja($fechaInicio, $fechaFin) {
        $query = "SELECT 
                    ccd.fecha,
                    ccd.monto_apertura,
                    ccd.monto_final,
                    SUM(CASE WHEN cc.tipo_movimiento = 'ingreso' THEN cc.monto ELSE 0 END) AS total_ingresos,
                    SUM(CASE WHEN cc.tipo_movimiento = 'egreso' THEN cc.monto ELSE 0 END) AS total_egresos
                  FROM caja_chica_diaria ccd
                  LEFT JOIN caja_chica cc ON ccd.fecha = cc.fecha
                  WHERE ccd.fecha BETWEEN :fechaInicio AND :fechaFin
                  GROUP BY ccd.fecha
                  ORDER BY ccd.fecha DESC";
        $stmt = $this->pdo->prepare($query);
        $stmt->execute([
            ":fechaInicio" => $fechaInicio,
            ":fechaFin" => $fechaFin
        ]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Obtener el reporte de ingresos por reservas (con filtros de agencia y guía)
    public function obtenerReporteIngresosReservas($fechaInicio, $fechaFin, $id_agencia = null, $id_guia = null) {
        $query = "SELECT 
                    rg.fecha_mes_y_año,
                    a.nombreAgencia,
                    g.nombreGuia,
                    rg.numero_pasajeros,
                    SUM(mp.costo_total) AS total_revenue,
                    rg.adelanto,
                    rg.totalidad,
                    rg.estado
                  FROM reserva_general rg
                  LEFT JOIN mesa m ON rg.id_reservaciongeneral = m.id_reservaciongeneral
                  LEFT JOIN mesa_productos mp ON m.id_mesa = mp.id_mesa
                  LEFT JOIN agencia a ON rg.id_agencia = a.id_agencia
                  LEFT JOIN guia g ON rg.id_guia = g.id_guia
                  WHERE rg.fecha_mes_y_año BETWEEN :fechaInicio AND :fechaFin";

        // Agregar filtros opcionales
        $params = [
            ":fechaInicio" => $fechaInicio,
            ":fechaFin" => $fechaFin
        ];

        if (!empty($id_agencia)) {
            $query .= " AND rg.id_agencia = :id_agencia";
            $params[":id_agencia"] = $id_agencia;
        }

        if (!empty($id_guia)) {
            $query .= " AND rg.id_guia = :id_guia";
            $params[":id_guia"] = $id_guia;
        }

        $query .= " GROUP BY rg.id_reservaciongeneral ORDER BY rg.fecha_mes_y_año DESC";

        $stmt = $this->pdo->prepare($query);
        $stmt->execute($params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}