document.addEventListener('DOMContentLoaded', function () {
    // Colores consistentes para los gráficos
    const colores = {
        pagado: '#28a745',
        sinPagar: '#dc3545',
        efectivo: '#28a745',
        tarjeta: '#007bff',
        transferencia: '#ffc107',
        mes: '#007bff',
        guia: '#17a2b8',
        agencia: '#ffc107',
        diaSemana: '#6f42c1'
    };

    // Opciones comunes para todos los gráficos
    const opcionesComunes = {
        plugins: {
            tooltip: {
                backgroundColor: 'rgba(0, 0, 0, 0.8)',
                titleFont: { size: 14 },
                bodyFont: { size: 12 },
                padding: 10
            },
            legend: {
                labels: {
                    font: { size: 12 }
                }
            }
        },
        animation: {
            duration: 1000,
            easing: 'easeInOutQuad'
        }
    };

    // Gráfico de reservaciones por estado (barras)
    const estadoCtx = document.getElementById('estadoChart').getContext('2d');
    new Chart(estadoCtx, {
        type: 'bar',
        data: {
            labels: ['Pagado', 'Sin Pagar'],
            datasets: [{
                label: 'Número de Reservaciones',
                data: [window.estadisticas.estados.pagado, window.estadisticas.estados.sinPagar],
                backgroundColor: [colores.pagado, colores.sinPagar],
                borderColor: [colores.pagado, colores.sinPagar],
                borderWidth: 1
            }]
        },
        options: {
            ...opcionesComunes,
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Número de Reservaciones',
                        font: { size: 14 }
                    }
                },
                x: {
                    title: {
                        display: true,
                        text: 'Estado',
                        font: { size: 14 }
                    }
                }
            },
            plugins: {
                ...opcionesComunes.plugins,
                legend: { display: false }
            }
        }
    });

    // Gráfico de métodos de pago (pastel)
    const metodoPagoCtx = document.getElementById('metodoPagoChart').getContext('2d');
    new Chart(metodoPagoCtx, {
        type: 'pie',
        data: {
            labels: ['Efectivo', 'Tarjeta', 'Transferencia'],
            datasets: [{
                label: 'Métodos de Pago',
                data: [
                    window.estadisticas.metodosPago.Efectivo,
                    window.estadisticas.metodosPago.Tarjeta,
                    window.estadisticas.metodosPago.Transferencia
                ],
                backgroundColor: [colores.efectivo, colores.tarjeta, colores.transferencia],
                borderColor: ['#fff', '#fff', '#fff'],
                borderWidth: 1
            }]
        },
        options: {
            ...opcionesComunes,
            plugins: {
                ...opcionesComunes.plugins,
                legend: {
                    position: 'bottom',
                    labels: {
                        font: { size: 12 }
                    }
                }
            }
        }
    });

    // Gráfico de reservaciones por mes (líneas)
    const mesCtx = document.getElementById('mesChart').getContext('2d');
    new Chart(mesCtx, {
        type: 'line',
        data: {
            labels: Object.keys(window.estadisticas.reservasPorMes),
            datasets: [{
                label: 'Reservaciones por Mes',
                data: Object.values(window.estadisticas.reservasPorMes),
                fill: true,
                backgroundColor: 'rgba(0, 123, 255, 0.1)',
                borderColor: colores.mes,
                tension: 0.3
            }]
        },
        options: {
            ...opcionesComunes,
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Número de Reservaciones',
                        font: { size: 14 }
                    }
                },
                x: {
                    title: {
                        display: true,
                        text: 'Mes',
                        font: { size: 14 }
                    }
                }
            }
        }
    });

    // Gráfico de ingresos por mes (barras apiladas)
    const ingresosMesCtx = document.getElementById('ingresosMesChart').getContext('2d');
    new Chart(ingresosMesCtx, {
        type: 'bar',
        data: {
            labels: Object.keys(window.estadisticas.ingresosPorMesPagado),
            datasets: [
                {
                    label: 'Pagado',
                    data: Object.values(window.estadisticas.ingresosPorMesPagado),
                    backgroundColor: colores.pagado,
                    borderColor: colores.pagado,
                    borderWidth: 1
                },
                {
                    label: 'Sin Pagar',
                    data: Object.values(window.estadisticas.ingresosPorMesSinPagar),
                    backgroundColor: colores.sinPagar,
                    borderColor: colores.sinPagar,
                    borderWidth: 1
                }
            ]
        },
        options: {
            ...opcionesComunes,
            scales: {
                x: {
                    stacked: true,
                    title: {
                        display: true,
                        text: 'Mes',
                        font: { size: 14 }
                    }
                },
                y: {
                    stacked: true,
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Ingresos ($)',
                        font: { size: 14 }
                    }
                }
            }
        }
    });

    // Gráfico de reservaciones por guía (barras horizontales)
    const guiaCtx = document.getElementById('guiaChart').getContext('2d');
    new Chart(guiaCtx, {
        type: 'bar',
        data: {
            labels: Object.keys(window.estadisticas.reservasPorGuia),
            datasets: [{
                label: 'Reservaciones por Guía',
                data: Object.values(window.estadisticas.reservasPorGuia),
                backgroundColor: colores.guia,
                borderColor: colores.guia,
                borderWidth: 1
            }]
        },
        options: {
            ...opcionesComunes,
            indexAxis: 'y',
            scales: {
                x: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Número de Reservaciones',
                        font: { size: 14 }
                    }
                },
                y: {
                    title: {
                        display: true,
                        text: 'Guía',
                        font: { size: 14 }
                    }
                }
            }
        }
    });

    // Gráfico de reservaciones por agencia (barras horizontales)
    const agenciaCtx = document.getElementById('agenciaChart').getContext('2d');
    new Chart(agenciaCtx, {
        type: 'bar',
        data: {
            labels: Object.keys(window.estadisticas.reservasPorAgencia),
            datasets: [{
                label: 'Reservaciones por Agencia',
                data: Object.values(window.estadisticas.reservasPorAgencia),
                backgroundColor: colores.agencia,
                borderColor: colores.agencia,
                borderWidth: 1
            }]
        },
        options: {
            ...opcionesComunes,
            indexAxis: 'y',
            scales: {
                x: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Número de Reservaciones',
                        font: { size: 14 }
                    }
                },
                y: {
                    title: {
                        display: true,
                        text: 'Agencia',
                        font: { size: 14 }
                    }
                }
            }
        }
    });

    // Gráfico de reservaciones por día de la semana (barras)
    const diaSemanaCtx = document.getElementById('diaSemanaChart').getContext('2d');
    new Chart(diaSemanaCtx, {
        type: 'bar',
        data: {
            labels: Object.keys(window.estadisticas.reservasPorDiaSemana),
            datasets: [{
                label: 'Reservaciones por Día',
                data: Object.values(window.estadisticas.reservasPorDiaSemana),
                backgroundColor: colores.diaSemana,
                borderColor: colores.diaSemana,
                borderWidth: 1
            }]
        },
        options: {
            ...opcionesComunes,
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: 'Número de Reservaciones',
                        font: { size: 14 }
                    }
                },
                x: {
                    title: {
                        display: true,
                        text: 'Día de la Semana',
                        font: { size: 14 }
                    }
                }
            }
        }
    });
});