<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/CajaChicaController.php';

// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Crear una instancia del controlador
$controller = new CajaChicaController($pdo);

// Procesar las acciones
$controller->registrarMovimiento();
$controller->registrarMontoApertura();
$controller->registrarMontoFinal();

// Obtener la fecha seleccionada (por GET o por defecto)
$fecha = $_GET['fecha'] ?? date('Y-m-d');
$data = $controller->listarMovimientos($fecha);
$movimientos = $data['movimientos'];
$productos_vendidos = $data['productos_vendidos'];
$monto_apertura = $data['monto_apertura'];
$monto_final = $data['monto_final'];
$ingresos_caja = $data['ingresos_caja'];
$ingresos_productos = $data['ingresos_productos'];
$total_ingresos = $data['total_ingresos'];
$egresos_caja = $data['egresos_caja'];
$saldo = $data['saldo'];
$fecha = $data['fecha'];

// Manejar mensajes de éxito o error
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Listado Caja Chica</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 16px;
        }
        .card {
            border-radius: 8px;
            box-shadow: 0 1.6px 8px rgba(0, 0, 0, 0.1);
            margin-bottom: 12px;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 8px 8px 0 0;
            padding: 8px 12px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .card-body {
            padding: 12px;
        }
        .form-control, .form-select {
            border-radius: 4px;
            font-size: 0.68rem;
            padding: 0.16rem 0.32rem;
        }
        .form-label {
            font-size: 0.68rem;
            margin-bottom: 0.16rem;
        }
        .btn {
            border-radius: 4px;
            font-size: 0.68rem;
            padding: 0.16rem 0.48rem;
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
        .movimiento-table, .producto-table {
            margin-top: 4px;
            font-size: 0.64rem;
        }
        .movimiento-table th, .movimiento-table td,
        .producto-table th, .producto-table td {
            vertical-align: middle;
            padding: 0.16rem 0.32rem;
        }
        .movimiento-table th, .producto-table th {
            background-color: #f8f9fa;
            font-size: 0.64rem;
        }
        .movimiento-table td, .producto-table td {
            font-size: 0.64rem;
        }
        .saldo-positivo {
            color: #28a745;
            font-weight: bold;
        }
        .saldo-negativo {
            color: #dc3545;
            font-weight: bold;
        }
        hr {
            margin: 0.4rem 0;
        }
    </style>
</head>
<body>
<?php include '../templates/header.php'; ?>
    <!-- Main Content -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-wallet me-2"></i> Caja Chica - Resumen Diario</h2>

        <!-- Formulario para seleccionar fecha -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-calendar-alt me-2"></i> Seleccionar Fecha</h5>
            </div>
            <div class="card-body">
                <form method="GET" action="ListadoCajaChica.php">
                    <div class="row g-2">
                        <div class="col-md-4">
                            <label for="fecha" class="form-label">Fecha:</label>
                            <input type="date" name="fecha" id="fecha" class="form-control" value="<?php echo htmlspecialchars($fecha); ?>" required>
                        </div>
                        <div class="col-md-2 align-self-end">
                            <button type="submit" class="btn btn-primary"><i class="fas fa-search me-2"></i> Filtrar</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Formulario para registrar monto de apertura -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-door-open me-2"></i> Registrar Monto de Apertura</h5>
            </div>
            <div class="card-body">
                <form method="POST" action="ListadoCajaChica.php">
                    <input type="hidden" name="fecha" value="<?php echo htmlspecialchars($fecha); ?>">
                    <div class="row g-2">
                        <div class="col-md-4">
                            <label for="monto_apertura" class="form-label">Monto de Apertura (S/):</label>
                            <input type="number" name="monto_apertura" id="monto_apertura" class="form-control" step="0.01" min="0" value="<?php echo htmlspecialchars($monto_apertura); ?>" required>
                        </div>
                        <div class="col-md-2 align-self-end">
                            <button type="submit" name="registrar_apertura" class="btn btn-success"><i class="fas fa-save me-2"></i> Registrar</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Formulario para registrar movimiento -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-plus-circle me-2"></i> Registrar Movimiento</h5>
            </div>
            <div class="card-body">
                <form method="POST" action="ListadoCajaChica.php">
                    <input type="hidden" name="fecha" value="<?php echo htmlspecialchars($fecha); ?>">
                    <div class="row g-2">
                        <div class="col-md-3">
                            <label for="tipo_movimiento" class="form-label">Tipo:</label>
                            <select name="tipo_movimiento" id="tipo_movimiento" class="form-select" required>
                                <option value="">Seleccionar tipo</option>
                                <option value="ingreso">Ingreso</option>
                                <option value="egreso">Egreso</option>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label for="monto" class="form-label">Monto (S/):</label>
                            <input type="number" name="monto" id="monto" class="form-control" step="0.01" min="0.01" required>
                        </div>
                        <div class="col-md-4">
                            <label for="descripcion" class="form-label">Descripción:</label>
                            <input type="text" name="descripcion" id="descripcion" class="form-control" required>
                        </div>
                        <div class="col-md-2 align-self-end">
                            <button type="submit" name="registrar_movimiento" class="btn btn-success"><i class="fas fa-save me-2"></i> Registrar</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Mostrar Resumen Diario -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-list me-2"></i> Resumen para <?php echo htmlspecialchars($fecha); ?></h5>
            </div>
            <div class="card-body">
                <div class="row mb-3">
                    <div class="col-md-3">
                        <p><strong>Monto de Apertura:</strong> S/ <?php echo number_format($monto_apertura, 2); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p><strong>Ingresos (Caja):</strong> S/ <?php echo number_format($ingresos_caja, 2); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p><strong>Ingresos (Productos):</strong> S/ <?php echo number_format($ingresos_productos, 2); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p><strong>Total Ingresos:</strong> S/ <?php echo number_format($total_ingresos, 2); ?></p>
                    </div>
                </div>
                <div class="row mb-3">
                    <div class="col-md-3">
                        <p><strong>Egresos (Caja):</strong> S/ <?php echo number_format($egresos_caja, 2); ?></p>
                    </div>
                    <div class="col-md-3">
                        <p><strong>Saldo Calculado:</strong> <span class="<?php echo $saldo >= 0 ? 'saldo-positivo' : 'saldo-negativo'; ?>">S/ <?php echo number_format($saldo, 2); ?></span></p>
                    </div>
                    <div class="col-md-3">
                        <p><strong>Monto de Cierre:</strong> S/ <?php echo number_format($monto_final, 2); ?></p>
                    </div>
                </div>

                <!-- Productos Vendidos -->
                <h6>Productos Vendidos</h6>
                <?php if (empty($productos_vendidos)): ?>
                    <p class="text-muted">No hay productos vendidos para esta fecha.</p>
                <?php else: ?>
                    <div class="producto-table">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>Producto</th>
                                    <th>Cant.</th>
                                    <th>Costo Total</th>
                                    <th>Fecha de Venta</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($productos_vendidos as $producto): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($producto['nombreProdu']); ?></td>
                                        <td><?php echo htmlspecialchars($producto['cantidad']); ?></td>
                                        <td>S/ <?php echo number_format($producto['costo_total'], 2); ?></td>
                                        <td><?php echo htmlspecialchars($producto['creado_en']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>

                <hr>

                <!-- Movimientos de Caja -->
                <h6>Movimientos de Caja</h6>
                <?php if (empty($movimientos)): ?>
                    <p class="text-muted">No hay movimientos para esta fecha.</p>
                <?php else: ?>
                    <div class="movimiento-table">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>Tipo</th>
                                    <th>Descripción</th>
                                    <th>Monto</th>
                                    <th>Hora</th>
                                    <th>Usuario</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($movimientos as $movimiento): ?>
                                    <tr>
                                        <td><?php echo ucfirst($movimiento['tipo_movimiento']); ?></td>
                                        <td><?php echo htmlspecialchars($movimiento['descripcion']); ?></td>
                                        <td class="<?php echo $movimiento['tipo_movimiento'] === 'ingreso' ? 'saldo-positivo' : 'saldo-negativo'; ?>">
                                            S/ <?php echo number_format($movimiento['monto'], 2); ?>
                                        </td>
                                        <td><?php echo htmlspecialchars($movimiento['hora']); ?></td>
                                        <td><?php echo htmlspecialchars($movimiento['username'] ?? 'N/A'); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Formulario para registrar monto final -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-door-closed me-2"></i> Registrar Monto de Cierre</h5>
            </div>
            <div class="card-body">
                <form method="POST" action="ListadoCajaChica.php">
                    <input type="hidden" name="fecha" value="<?php echo htmlspecialchars($fecha); ?>">
                    <div class="row g-2">
                        <div class="col-md-4">
                            <label for="monto_final" class="form-label">Monto de Cierre (S/):</label>
                            <input type="number" name="monto_final" id="monto_final" class="form-control" step="0.01" min="0" value="<?php echo htmlspecialchars($monto_final); ?>" required>
                        </div>
                        <div class="col-md-2 align-self-end">
                            <button type="submit" name="registrar_cierre" class="btn btn-danger"><i class="fas fa-save me-2"></i> Registrar</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListadoCajaChica.php?fecha=<?php echo urlencode($fecha); ?>';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='ListadoCajaChica.php?fecha=<?php echo urlencode($fecha); ?>';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListadoCajaChica.php?fecha=<?php echo urlencode($fecha); ?>';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='ListadoCajaChica.php?fecha=<?php echo urlencode($fecha); ?>';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>