<?php
// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/ReporteController.php';

// Crear una instancia del controlador
$controller = new ReporteController($pdo);

// Procesar el formulario de generación de reportes
$controller->generarReporte();

// Procesar la exportación a Excel
$controller->exportarExcel();

// Obtener las listas de agencias y guías para los filtros
$filtros = $controller->obtenerFiltros();
$agencias = $filtros['agencias'];
$guias = $filtros['guias'];

// Incluir el header
include '../templates/header.php';

// Manejar mensajes de éxito o error
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';

// Obtener los datos del reporte desde la sesión (la sesión ya está iniciada en header.php)
$datosReporte = $_SESSION['datos_reporte'] ?? [];
$tipoReporte = $_SESSION['tipo_reporte'] ?? '';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Listado de Reportes</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 20px;
        }
        .card {
            border-radius: 10px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            margin-bottom: 15px;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 10px 10px 0 0;
            padding: 10px 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .card-body {
            padding: 15px;
        }
        .form-control {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.75rem;
        }
        .table {
            font-size: 0.9rem;
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
    </style>
</head>
<body>
    <!-- Contenido Principal -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-chart-line me-2"></i> Reportes</h2>

        <!-- Formulario para generar reportes -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-filter me-2"></i> Filtros de Reporte</h5>
            </div>
            <div class="card-body">
                <form method="POST">
                    <div class="row g-2">
                        <div class="col-md-3">
                            <label for="tipo_reporte" class="form-label">Tipo de Reporte: <span class="text-danger">*</span></label>
                            <select name="tipo_reporte" id="tipo_reporte" class="form-control" required>
                                <option value="">Seleccionar...</option>
                                <option value="flujo_caja">Flujo de Caja Diario</option>
                                <option value="ingresos_reservas">Ingresos por Reservas</option>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label for="fecha_inicio" class="form-label">Fecha Inicio: <span class="text-danger">*</span></label>
                            <input type="date" name="fecha_inicio" id="fecha_inicio" class="form-control" required>
                        </div>
                        <div class="col-md-3">
                            <label for="fecha_fin" class="form-label">Fecha Fin: <span class="text-danger">*</span></label>
                            <input type="date" name="fecha_fin" id="fecha_fin" class="form-control" required>
                        </div>
                        <div class="col-md-3">
                            <label for="id_agencia" class="form-label">Agencia:</label>
                            <select name="id_agencia" id="id_agencia" class="form-control">
                                <option value="">Todas las agencias</option>
                                <?php foreach ($agencias as $agencia): ?>
                                    <option value="<?php echo htmlspecialchars($agencia['id_agencia']); ?>">
                                        <?php echo htmlspecialchars($agencia['nombreAgencia']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="col-md-3">
                            <label for="id_guia" class="form-label">Guía:</label>
                            <select name="id_guia" id="id_guia" class="form-control">
                                <option value="">Todos los guías</option>
                                <?php foreach ($guias as $guia): ?>
                                    <option value="<?php echo htmlspecialchars($guia['id_guia']); ?>">
                                        <?php echo htmlspecialchars($guia['nombreGuia']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>

                    <div class="mt-3">
                        <button type="submit" name="generar_reporte" class="btn btn-primary"><i class="fas fa-chart-bar me-2"></i> Generar Reporte</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- Mostrar los datos del reporte -->
        <?php if (!empty($datosReporte)): ?>
            <div class="card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fas fa-table me-2"></i> Resultados del Reporte</h5>
                    <!-- Botón para exportar a Excel -->
                    <form method="POST" style="display: inline;">
                        <button type="submit" name="exportar_excel" class="btn btn-success btn-sm">
                            <i class="fas fa-file-excel me-2"></i> Exportar a Excel
                        </button>
                    </form>
                </div>
                <div class="card-body">
                    <?php if ($tipoReporte === "flujo_caja"): ?>
                        <table class="table table-bordered table-striped">
                            <thead>
                                <tr>
                                    <th>Fecha</th>
                                    <th>Monto Apertura</th>
                                    <th>Monto Final</th>
                                    <th>Total Ingresos</th>
                                    <th>Total Egresos</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($datosReporte as $fila): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($fila['fecha']); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['monto_apertura'], 2)); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['monto_final'], 2)); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['total_ingresos'], 2)); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['total_egresos'], 2)); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php elseif ($tipoReporte === "ingresos_reservas"): ?>
                        <table class="table table-bordered table-striped">
                            <thead>
                                <tr>
                                    <th>Fecha</th>
                                    <th>Agencia</th>
                                    <th>Guía</th>
                                    <th>Número de Pasajeros</th>
                                    <th>Ingresos Totales</th>
                                    <th>Adelanto</th>
                                    <th>Total</th>
                                    <th>Estado</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($datosReporte as $fila): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($fila['fecha_mes_y_año']); ?></td>
                                        <td><?php echo htmlspecialchars($fila['nombreAgencia']); ?></td>
                                        <td><?php echo htmlspecialchars($fila['nombreGuia']); ?></td>
                                        <td><?php echo htmlspecialchars($fila['numero_pasajeros']); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['total_revenue'] ?? 0, 2)); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['adelanto'], 2)); ?></td>
                                        <td><?php echo htmlspecialchars(number_format($fila['totalidad'], 2)); ?></td>
                                        <td><?php echo htmlspecialchars($fila['estado']); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    <?php endif; ?>
                </div>
            </div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListaReporte.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='ListaReporte.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListaReporte.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='ListaReporte.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>