<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../config/config.php';

// Incluir controlador
require_once '../controllers/AgenciaController.php';

// Crear una instancia del controlador
$controller = new AgenciaController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_agencia"])) {
        $controller->agregarAgencia();
    }
    if (isset($_POST["editar_agencia"])) {
        $controller->editarAgencia();
    }
    if (isset($_POST["eliminar_agencia"])) {
        $controller->eliminarAgencia();
    }
}

// Obtener la lista de agencias para mostrar
$agencias = $controller->listarAgencias();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Agencias</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="content">
        <h2>Gestión de Agencias</h2>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar una nueva agencia -->
        <form action="agencia.php" method="POST" class="row g-3 mb-3">
            <div class="col-md-3">
                <label for="nombreAgencia" class="form-label">Nombre:</label>
                <input type="text" name="nombreAgencia" id="nombreAgencia" class="form-control" required>
            </div>
            <div class="col-md-3">
                <label for="fax" class="form-label">Fax:</label>
                <input type="text" name="fax" id="fax" class="form-control">
            </div>
            <div class="col-md-3">
                <label for="fechaInicialCredito" class="form-label">Fecha Inicial Crédito:</label>
                <input type="date" name="fechaInicialCredito" id="fechaInicialCredito" class="form-control">
            </div>
            <div class="col-md-2">
                <label for="fechaFinalCredito" class="form-label">Fecha Final Crédito:</label>
                <input type="date" name="fechaFinalCredito" id="fechaFinalCredito" class="form-control">
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" name="agregar_agencia" class="btn btn-primary">Agregar</button>
            </div>
        </form>

        <h3>Lista de Agencias</h3>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Fax</th>
                    <th>Fecha Inicial Crédito</th>
                    <th>Fecha Final Crédito</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($agencias as $agencia): ?>
                <tr>
                    <td><?php echo htmlspecialchars($agencia["id_agencia"]); ?></td>
                    <td><?php echo htmlspecialchars($agencia["nombreAgencia"]); ?></td>
                    <td><?php echo htmlspecialchars($agencia["fax"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($agencia["fechaInicialCredito"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($agencia["fechaFinalCredito"] ?? 'N/A'); ?></td>
                    <td>
                        <!-- Formulario para editar agencia -->
                        <form action="agencia.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_agencia" value="<?php echo $agencia["id_agencia"]; ?>">
                            <input type="text" name="nombreAgencia" value="<?php echo htmlspecialchars($agencia["nombreAgencia"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 100px;">
                            <input type="text" name="fax" value="<?php echo htmlspecialchars($agencia["fax"] ?? ''); ?>" class="form-control form-control-sm" style="display:inline; width: 80px;">
                            <input type="date" name="fechaInicialCredito" value="<?php echo htmlspecialchars($agencia["fechaInicialCredito"] ?? ''); ?>" class="form-control form-control-sm" style="display:inline; width: 120px;">
                            <input type="date" name="fechaFinalCredito" value="<?php echo htmlspecialchars($agencia["fechaFinalCredito"] ?? ''); ?>" class="form-control form-control-sm" style="display:inline; width: 120px;">
                            <button type="submit" name="editar_agencia" class="btn btn-warning btn-sm">Actualizar</button>
                        </form>
                        <!-- Formulario para eliminar agencia -->
                        <form action="agencia.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_agencia" value="<?php echo $agencia["id_agencia"]; ?>">
                            <button type="submit" name="eliminar_agencia" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta agencia?')">Eliminar</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>