<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/AgenciaController.php';

// Crear una instancia del controlador
$controller = new AgenciaController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_agencia"])) {
        $controller->agregarAgencia();
    }
    if (isset($_POST["eliminar_agencia"])) {
        $controller->eliminarAgencia();
    }
}

// Obtener la lista de agencias para mostrar
$agencias = $controller->listarAgencias();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Crear Agencia</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 900px;
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .table th, .table td {
            font-size: 0.9rem;
            vertical-align: middle;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Crear Agencia</h1>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar una nueva agencia -->
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="agregar_agencia" value="1">
            <div class="col-md-2">
                <label for="nombreAgencia" class="form-label">Nombre:</label>
                <input type="text" name="nombreAgencia" id="nombreAgencia" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="fax" class="form-label">Fax:</label>
                <input type="text" name="fax" id="fax" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="fechaInicialCredito" class="form-label">Fecha Inicial Crédito:</label>
                <input type="date" name="fechaInicialCredito" id="fechaInicialCredito" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="fechaFinalCredito" class="form-label">Fecha Final Crédito:</label>
                <input type="date" name="fechaFinalCredito" id="fechaFinalCredito" class="form-control" required>
            </div>
            <div class="col-md-1">
                <label for="precio" class="form-label">Precio:</label>
                <input type="number" step="0.01" name="precio" id="precio" class="form-control" required>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Guardar</button>
            </div>
        </form>

        <h3>Lista de Agencias</h3>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Fax</th>
                    <th>Fecha Inicial Crédito</th>
                    <th>Fecha Final Crédito</th>
                    <th>Precio</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($agencias)): ?>
                    <tr>
                        <td colspan="7" class="text-center">No hay agencias registradas.</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($agencias as $agencia): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($agencia["id_agencia"]); ?></td>
                        <td><?php echo htmlspecialchars($agencia["nombreAgencia"]); ?></td>
                        <td><?php echo htmlspecialchars($agencia["fax"]); ?></td>
                        <td><?php echo htmlspecialchars($agencia["fechaInicialCredito"]); ?></td>
                        <td><?php echo htmlspecialchars($agencia["fechaFinalCredito"]); ?></td>
                        <td><?php echo htmlspecialchars($agencia["precio"] ?? 'N/A'); ?></td>
                        <td>
                            <a href="agenciaedit.php?id=<?php echo $agencia["id_agencia"]; ?>" class="btn btn-warning btn-sm">Actualizar</a>
                            <form method="POST" style="display:inline;">
                                <input type="hidden" name="eliminar_agencia" value="1">
                                <input type="hidden" name="id_agencia" value="<?php echo $agencia["id_agencia"]; ?>">
                                <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta agencia?')">Eliminar</button>
                            </form>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>