<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Verificar si el usuario está autenticado
require_once '../../config/auth.php';
requireLogin();

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/AgenciaController.php';

// Crear una instancia del controlador
$controller = new AgenciaController($pdo);

// Obtener la agencia a editar
if (isset($_GET['id'])) {
    $id = intval($_GET['id']);
    $agencias = $controller->listarAgencias();
    $agencia = array_filter($agencias, fn($a) => $a['id_agencia'] == $id);
    $agencia = reset($agencia);

    if (!$agencia) {
        header("Location: agencialist.php?error=Agencia no encontrada.");
        exit();
    }
} else {
    header("Location: agencialist.php?error=ID de agencia no especificado.");
    exit();
}

if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_agencia"])) {
    $controller->editarAgencia();
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Editar Agencia</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 900px;
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Editar Agencia</h1>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para editar una agencia -->
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="editar_agencia" value="1">
            <input type="hidden" name="id_agencia" value="<?php echo $agencia['id_agencia']; ?>">
            <div class="col-md-2">
                <label for="nombreAgencia" class="form-label">Nombre:</label>
                <input type="text" name="nombreAgencia" id="nombreAgencia" class="form-control" value="<?php echo htmlspecialchars($agencia['nombreAgencia']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="fax" class="form-label">Fax:</label>
                <input type="text" name="fax" id="fax" class="form-control" value="<?php echo htmlspecialchars($agencia['fax']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="fechaInicialCredito" class="form-label">Fecha Inicial Crédito:</label>
                <input type="date" name="fechaInicialCredito" id="fechaInicialCredito" class="form-control" value="<?php echo htmlspecialchars($agencia['fechaInicialCredito']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="fechaFinalCredito" class="form-label">Fecha Final Crédito:</label>
                <input type="date" name="fechaFinalCredito" id="fechaFinalCredito" class="form-control" value="<?php echo htmlspecialchars($agencia['fechaFinalCredito']); ?>" required>
            </div>
            <div class="col-md-1">
                <label for="precio" class="form-label">Precio:</label>
                <input type="number" step="0.01" name="precio" id="precio" class="form-control" value="<?php echo htmlspecialchars($agencia['precio'] ?? ''); ?>" required>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Actualizar</button>
            </div>
        </form>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>