<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
session_start();

// Verificar si el usuario está autenticado
require_once '../../config/auth.php';

// Verificar si el usuario está autenticado
requireLogin();

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/AgenciaController.php';

// Crear una instancia del controlador
$controller = new AgenciaController($pdo);

// Obtener la lista de agencias para mostrar
$agencias = $controller->listarAgencias();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Lista de Agencias</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 900px;
            margin: 0 auto;
            padding: 20px;
        }
        .table th, .table td {
            font-size: 0.9rem;
            vertical-align: middle;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Lista de Agencias</h1>

        <!-- Enlace para crear una nueva agencia -->
        <a href="agenciacreate.php" class="btn btn-primary btn-sm mb-3">Nueva Agencia</a>

        <!-- Tabla para listar las agencias -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Fax</th>
                    <th>Fecha Inicial Crédito</th>
                    <th>Fecha Final Crédito</th>
                    <th>Precio</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($agencias)): ?>
                    <tr>
                        <td colspan="7" class="text-center">No hay agencias registradas.</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($agencias as $agencia): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($agencia['id_agencia']); ?></td>
                        <td><?php echo htmlspecialchars($agencia['nombreAgencia']); ?></td>
                        <td><?php echo htmlspecialchars($agencia['fax']); ?></td>
                        <td><?php echo htmlspecialchars($agencia['fechaInicialCredito']); ?></td>
                        <td><?php echo htmlspecialchars($agencia['fechaFinalCredito']); ?></td>
                        <td><?php echo htmlspecialchars($agencia['precio'] ?? 'N/A'); ?></td>
                        <td>
                            <a href="agenciaedit.php?id=<?php echo $agencia['id_agencia']; ?>" class="btn btn-warning btn-sm">Editar</a>
                            <form method="POST" action="agenciacreate.php" style="display:inline;">
                                <input type="hidden" name="eliminar_agencia" value="1">
                                <input type="hidden" name="id_agencia" value="<?php echo $agencia['id_agencia']; ?>">
                                <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta agencia?')">Eliminar</button>
                            </form>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>