<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../config/config.php';

// Incluir controlador
require_once '../controllers/GuiaController.php';

// Crear una instancia del controlador
$controller = new GuiaController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_guia"])) {
        $controller->agregarGuia();
    }
    if (isset($_POST["editar_guia"])) {
        $controller->editarGuia();
    }
    if (isset($_POST["eliminar_guia"])) {
        $controller->eliminarGuia();
    }
}

// Obtener la lista de guías para mostrar
$guias = $controller->listarGuias();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Guías</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="content">
        <h2>Gestión de Guías</h2>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar un nuevo guía -->
        <form action="guia.php" method="POST" class="row g-3 mb-3">
            <div class="col-md-3">
                <label for="nombreGuia" class="form-label">Nombre:</label>
                <input type="text" name="nombreGuia" id="nombreGuia" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="tipo_documento" class="form-label">Tipo Documento:</label>
                <select name="tipo_documento" id="tipo_documento" class="form-select" required>
                    <option value="">Seleccione</option>
                    <option value="DNI">DNI</option>
                    <option value="RCU">RCU</option>
                </select>
            </div>
            <div class="col-md-2">
                <label for="inicio_credito" class="form-label">Inicio Crédito:</label>
                <input type="date" name="inicio_credito" id="inicio_credito" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="celular" class="form-label">Celular:</label>
                <input type="text" name="celular" id="celular" class="form-control" placeholder="+51 987654321" required>
            </div>
            <div class="col-md-2 align-self-end">
                <button type="submit" name="agregar_guia" class="btn btn-primary">Agregar</button>
            </div>
        </form>

        <h3>Lista de Guías</h3>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Tipo Documento</th>
                    <th>Inicio Crédito</th>
                    <th>Celular</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($guias as $guia): ?>
                <tr>
                    <td><?php echo htmlspecialchars($guia["id_guia"]); ?></td>
                    <td><?php echo htmlspecialchars($guia["nombreGuia"]); ?></td>
                    <td><?php echo htmlspecialchars($guia["tipo_documento"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($guia["inicio_credito"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($guia["celular"] ?? 'N/A'); ?></td>
                    <td>
                        <!-- Formulario para editar guía -->
                        <form action="guia.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_guia" value="<?php echo $guia["id_guia"]; ?>">
                            <input type="text" name="nombreGuia" value="<?php echo htmlspecialchars($guia["nombreGuia"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 150px;">
                            <select name="tipo_documento" class="form-select form-select-sm" required style="display:inline; width: 100px;">
                                <option value="DNI" <?php echo ($guia["tipo_documento"] == 'DNI') ? 'selected' : ''; ?>>DNI</option>
                                <option value="RCU" <?php echo ($guia["tipo_documento"] == 'RCU') ? 'selected' : ''; ?>>RCU</option>
                            </select>
                            <input type="date" name="inicio_credito" value="<?php echo htmlspecialchars($guia["inicio_credito"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 150px;">
                            <input type="text" name="celular" value="<?php echo htmlspecialchars($guia["celular"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 150px;" placeholder="+51 987654321">
                            <button type="submit" name="editar_guia" class="btn btn-warning btn-sm">Actualizar</button>
                        </form>
                        <!-- Formulario para eliminar guía -->
                        <form action="guia.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_guia" value="<?php echo $guia["id_guia"]; ?>">
                            <button type="submit" name="eliminar_guia" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar este guía?')">Eliminar</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>