<?php
// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/GuiaController.php';

// Crear una instancia del controlador
$controller = new GuiaController($pdo);

// Obtener el ID del guía desde la URL
$id_guia = isset($_GET['id']) ? intval($_GET['id']) : 0;

// Validar que se haya proporcionado un ID válido
if ($id_guia <= 0) {
    header("Location: guialist.php?error=ID de guía inválido.");
    exit();
}

// Obtener los datos del guía a editar
$guias = $controller->listarGuias();
$guia = null;
foreach ($guias as $g) {
    if ($g['id_guia'] == $id_guia) {
        $guia = $g;
        break;
    }
}

// Verificar si el guía existe
if (!$guia) {
    header("Location: guialist.php?error=Guía no encontrado.");
    exit();
}

// Procesar el formulario de edición
$controller->editarGuia();

// Ahora que hemos manejado la lógica, podemos incluir el header y el resto del HTML
include '../templates/header.php';

// Manejar mensajes de éxito o error
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Editar Guía</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 20px;
        }
        .card {
            border-radius: 10px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            margin-bottom: 15px;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 10px 10px 0 0;
            padding: 10px 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .card-body {
            padding: 15px;
        }
        .form-control {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.75rem;
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
    </style>
</head>
<body>
    <!-- Main Content -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-user-edit me-2"></i> Editar Guía</h2>

        <!-- Formulario para editar el guía -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-edit me-2"></i> Actualizar Datos del Guía</h5>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Campo oculto para el ID del guía -->
                    <input type="hidden" name="id_guia" value="<?php echo htmlspecialchars($guia['id_guia']); ?>">

                    <div class="row g-2">
                        <div class="col-md-6">
                            <label for="nombreGuia" class="form-label">Nombre:</label>
                            <input type="text" name="nombreGuia" id="nombreGuia" class="form-control" value="<?php echo htmlspecialchars($guia['nombreGuia']); ?>" required>
                        </div>
                        <div class="col-md-6">
                            <label for="tipo_documento" class="form-label">Tipo de Documento:</label>
                            <select name="tipo_documento" id="tipo_documento" class="form-control" required>
                                <option value="RCU" <?php if ($guia['tipo_documento'] === 'RCU') echo 'selected'; ?>>RCU</option>
                                <option value="DNI" <?php if ($guia['tipo_documento'] === 'DNI') echo 'selected'; ?>>DNI</option>
                            </select>
                        </div>
                        <div class="col-md-6">
                            <label for="inicio_credito" class="form-label">Inicio de Crédito:</label>
                            <input type="date" name="inicio_credito" id="inicio_credito" class="form-control" value="<?php echo htmlspecialchars($guia['inicio_credito']); ?>" required>
                        </div>
                        <div class="col-md-6">
                            <label for="celular" class="form-label">Celular (ej. +51 987654321):</label>
                            <input type="text" name="celular" id="celular" class="form-control" value="<?php echo htmlspecialchars($guia['celular']); ?>" required pattern="^\+\d{1,3}\s\d{9}$" title="El formato debe ser como +51 987654321">
                        </div>
                    </div>

                    <div class="mt-3">
                        <button type="submit" name="editar_guia" class="btn btn-primary"><i class="fas fa-save me-2"></i> Actualizar</button>
                        <a href="guialist.php" class="btn btn-secondary"><i class="fas fa-arrow-left me-2"></i> Cancelar</a>
                    </div>
                </form>
            </div>
        </div>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='guialist.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='guialist.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='guialist.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='guialist.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>