<?php
// Iniciar la sesión
session_start();

// Si el usuario ya está autenticado, redirigir a reservalist.php
if (isset($_SESSION['user_id'])) {
    header("Location: reserva/reservalist.php"); // Corregir la redirección
    exit();
}

// Incluir configuración y controlador
require_once '../config/config.php';
require_once '../controllers/LoginController.php';

$controller = new LoginController($pdo);

// Procesar el login si se envía el formulario
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["login"])) {
    $controller->login();
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Iniciar Sesión - Terraza Andina</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        body {
            /* Fondo con gradiente terroso y cálido inspirado en los Andes */
            background: linear-gradient(135deg, #8B5A2B, #D2B48C);
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
            font-family: 'Poppins', sans-serif;
            position: relative;
            overflow: hidden;
        }
        /* Capa de textura para simular piedra o madera */
        body::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: url('https://www.transparenttextures.com/patterns/wood-pattern.png') repeat;
            opacity: 0.1;
            z-index: -1;
        }
        .login-container {
            max-width: 400px;
            width: 100%;
            padding: 30px;
            background-color: #ffffff;
            border-radius: 15px;
            box-shadow: 0 10px 30px rgba(0, 0, 0, 0.2);
            text-align: center;
            animation: fadeIn 0.5s ease-in-out;
            border: 2px solid #A0522D; /* Borde con un tono terroso */
        }
        .logo {
            max-width: 150px;
            margin-bottom: 15px;
        }
        .welcome-text {
            font-size: 1.5rem;
            font-weight: 600;
            color: #A0522D; /* Marrón cálido para el texto de bienvenida */
            margin-bottom: 10px;
            text-shadow: 1px 1px 2px rgba(0, 0, 0, 0.1);
        }
        .subtitle {
            font-size: 1rem;
            color: #555;
            margin-bottom: 20px;
        }
        .form-control {
            font-size: 0.9rem;
            padding: 0.75rem;
            border-radius: 8px;
            border: 1px solid #ddd;
            transition: border-color 0.3s ease;
        }
        .form-control:focus {
            border-color: #A0522D; /* Marrón cálido para el foco */
            box-shadow: 0 0 5px rgba(160, 82, 45, 0.3);
        }
        .form-label {
            font-size: 0.9rem;
            color: #555;
        }
        .btn-primary {
            background: linear-gradient(90deg, #A0522D, #CD853F); /* Gradiente terroso */
            border: none;
            padding: 10px;
            font-size: 1rem;
            font-weight: 500;
            border-radius: 8px;
            transition: transform 0.2s ease, background 0.3s ease;
        }
        .btn-primary:hover {
            background: linear-gradient(90deg, #CD853F, #A0522D);
            transform: translateY(-2px);
        }
        .alert {
            font-size: 0.9rem;
            border-radius: 8px;
        }
        .input-group-text {
            background-color: #f8f9fa;
            border: 1px solid #ddd;
            border-radius: 8px 0 0 8px;
        }
        .forgot-password {
            display: block;
            margin-top: 10px;
            font-size: 0.85rem;
            color: #A0522D; /* Marrón cálido para el enlace */
            text-decoration: none;
            transition: color 0.3s ease;
        }
        .forgot-password:hover {
            color: #CD853F; /* Tono más claro al pasar el mouse */
        }
        @keyframes fadeIn {
            from {
                opacity: 0;
                transform: translateY(20px);
            }
            to {
                opacity: 1;
                transform: translateY(0);
            }
        }
    </style>
</head>
<body>
    <div class="login-container">
        <!-- Logo -->
        <img src="../public/imagenes/logo.png" alt="Terraza Andina Logo" class="logo">

        <!-- Mensaje de bienvenida -->
        <div class="welcome-text">Bienvenido al Sistema de Terraza Andina</div>
        <div class="subtitle">Inicia sesión para gestionar tus reservas</div>

        <!-- Mostrar mensajes de éxito o error -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario de login -->
        <form method="POST">
            <input type="hidden" name="login" value="1">
            <div class="mb-3">
                <label for="username" class="form-label">Nombre de Usuario:</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-user"></i></span>
                    <input type="text" name="username" id="username" class="form-control" required>
                </div>
            </div>
            <div class="mb-3">
                <label for="password" class="form-label">Contraseña:</label>
                <div class="input-group">
                    <span class="input-group-text"><i class="fas fa-lock"></i></span>
                    <input type="password" name="password" id="password" class="form-control" required>
                </div>
            </div>
            <button type="submit" class="btn btn-primary w-100">Iniciar Sesión</button>
            <!-- Enlace para recuperar contraseña -->
            <a href="#" class="forgot-password">¿Olvidaste tu contraseña?</a>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>