<?php
// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/MesaController.php';

// Incluir la librería FPDF
require_once '../../libs/fpdf/fpdf.php';

// Crear una instancia del controlador
$controller = new MesaController($pdo);

// Procesar la actualización del estado de la mesa
$controller->actualizarEstadoMesa();

// Procesar la adición de productos
$controller->agregarProductoMesa();

// Procesar la actualización del estado de pago
$controller->actualizarEstadoPagoProducto();

// Verificar si se solicitó generar un PDF
if (isset($_GET['action']) && $_GET['action'] === 'imprimir' && isset($_GET['id_mesa_producto'])) {
    $id_mesa_producto = $_GET['id_mesa_producto'];
    $fecha = $_GET['fecha'] ?? date('Y-m-d');

    // Obtener los datos de las mesas para la fecha
    $data = $controller->listarMesas($fecha);
    $mesas = $data['mesas'];

    // Buscar el producto específico dentro de las mesas
    $producto_encontrado = null;
    $agencia = '';
    $fecha_mesa = $fecha;

    foreach ($mesas as $mesa) {
        if (!empty($mesa['productos'])) {
            foreach ($mesa['productos'] as $producto) {
                if ($producto['id_mesa_producto'] == $id_mesa_producto) {
                    $producto_encontrado = $producto;
                    $agencia = $mesa['nombreAgencia'];
                    $fecha_mesa = $mesa['fecha'];
                    break 2; // Salir de ambos bucles
                }
            }
        }
    }

    if (!$producto_encontrado) {
        die("Error: Product not found for id_mesa_producto: " . htmlspecialchars($id_mesa_producto));
    }

    // Generar el PDF con tamaño de 80 mm de ancho
    $pdf = new FPDF('P', 'mm', [80, 110]); // Ancho: 80 mm, Alto: 120 mm (ajustado para más contenido)
    $pdf->AddPage();
    $pdf->SetFont('Arial', 'B', 10);

    // Encabezado del PDF (en inglés)
    $pdf->Cell(0, 1, 'Terraza Andina', 0, 1, 'C');
    $pdf->Cell(0, 8, 'Consumption Ticket', 0, 1, 'C');
    $pdf->Cell(0, 2, $agencia, 0, 1, 'C');
    $pdf->SetFont('Arial', '', 8);
    $pdf->Cell(0, 5, 'Date: ' . date('d/m/Y', strtotime($fecha_mesa)), 0, 1, 'C');
    $pdf->Cell(0, 5, 'Time: ' . date('H:i:s'), 0, 1, 'C');
    $pdf->Cell(0, 5, 'Status: ' . ucfirst($producto_encontrado['estado_pago']), 0, 1, 'C');
    $pdf->Ln(3);

    // Línea divisoria
    $pdf->SetLineWidth(0.3);
    $pdf->Line(2, $pdf->GetY(), 75, $pdf->GetY()); // Ajustado para centrar (5 mm de margen a cada lado)
    $pdf->Ln(3);

    // Tabla con un solo producto (en inglés)
    $pdf->SetFont('Arial', 'B', 8);
    $pdf->SetFillColor(200, 220, 255);
    $pdf->Cell(30, 6, 'Product', 1, 0, 'C', true);
    $pdf->Cell(10, 6, 'Qty', 1, 0, 'C', true);
    $pdf->Cell(25, 6, 'Cost', 1, 1, 'C', true);

    $pdf->SetFont('Arial', '', 8);
    $pdf->Cell(30, 6, $producto_encontrado['nombreProdu'], 1);
    $pdf->Cell(10, 6, $producto_encontrado['cantidad'], 1, 0, 'C');
    $pdf->Cell(25, 6, 'S/ ' . number_format($producto_encontrado['costo_total'], 2), 1, 1, 'R');

    // Línea divisoria
    $pdf->Ln(3);
    $pdf->Line(2, $pdf->GetY(), 75, $pdf->GetY());
    $pdf->Ln(3);

    // Total (en inglés)
    $pdf->SetFont('Arial', 'B', 9);
    $pdf->Cell(45, 1, 'Total:', 0, 0, 'R');
    $pdf->Cell(20, 1, 'S/ ' . number_format($producto_encontrado['costo_total'], 2), 0, 1, 'R');

    // Línea divisoria
    $pdf->Ln(3);
    $pdf->Line(2, $pdf->GetY(), 75, $pdf->GetY());
    $pdf->Ln(5);

    // Comentario al final (en inglés)
    $pdf->SetFont('Arial', '', 10);
    $pdf->MultiCell(0, 4, 'This ticket confirms the payment of your consumption at the establishment, please keep it until you leave the premises.', 0, 'C');

    // Ajustar la altura de la página dinámicamente
    $pdf->SetY($pdf->GetY() + 5); // Espacio adicional al final

    // Salida del PDF (mostrar en el navegador)
    $filename = 'Consumption_Ticket_' . $agencia . '_' . str_replace(' ', '_', $producto_encontrado['nombreProdu']) . '_' . date('Ymd_His') . '.pdf';
    $pdf->Output('I', $filename);
    exit();
}

// Obtener la fecha seleccionada (por GET o por defecto)
$fecha = $_GET['fecha'] ?? date('Y-m-d');
$data = $controller->listarMesas($fecha);
$mesas = $data['mesas'];
$fecha = $data['fecha'];
$productos = $data['productos'];

// Manejar mensajes de éxito o error
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';

// Incluir el header
include '../templates/header.php';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Mesas</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 16px; /* Reducido de 20px (20%) */
        }
        .card {
            border-radius: 8px; /* Reducido de 10px (20%) */
            box-shadow: 0 1.6px 8px rgba(0, 0, 0, 0.1); /* Reducido de 2px 10px (20%) */
            margin-bottom: 12px; /* Reducido de 15px (20%) */
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 8px 8px 0 0; /* Reducido de 10px (20%) */
            padding: 8px 12px; /* Reducido de 10px 15px (20%) */
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .card-body {
            padding: 12px; /* Reducido de 15px (20%) */
        }
        .form-control, .form-select {
            border-radius: 4px; /* Reducido de 5px (20%) */
            font-size: 0.68rem; /* Reducido de 0.85rem (20%) */
            padding: 0.16rem 0.32rem; /* Reducido de 0.2rem 0.4rem (20%) */
        }
        .form-label {
            font-size: 0.68rem; /* Reducido de 0.85rem (20%) */
            margin-bottom: 0.16rem; /* Reducido de 0.2rem (20%) */
        }
        .btn {
            border-radius: 4px; /* Reducido de 5px (20%) */
            font-size: 0.68rem; /* Reducido de 0.85rem (20%) */
            padding: 0.16rem 0.48rem; /* Reducido de 0.2rem 0.6rem (20%) */
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
        /* Estilos para las mesas como tarjetas */
        .mesa-card {
            border: 1.6px solid #007bff; /* Reducido de 2px (20%) */
            border-radius: 12px; /* Reducido de 15px (20%) */
            background-color: #ffffff;
            box-shadow: 0 3.2px 6.4px rgba(0, 0, 0, 0.1); /* Reducido de 4px 8px (20%) */
            transition: transform 0.2s;
            min-height: 360px; /* Reducido de 450px (20%) */
            display: flex;
            flex-direction: column;
            justify-content: space-between;
        }
        .mesa-card:hover {
            transform: scale(1.03);
        }
        .mesa-header {
            background-color: #007bff;
            color: white;
            border-radius: 10.4px 10.4px 0 0; /* Reducido de 13px (20%) */
            padding: 6.4px; /* Reducido de 8px (20%) */
            text-align: center;
            font-weight: bold;
            font-size: 0.8rem; /* Reducido de 1rem (20%) */
        }
        .mesa-body {
            padding: 8px; /* Reducido de 10px (20%) */
            flex-grow: 1;
        }
        .mesa-body p {
            margin: 0.16rem 0; /* Reducido de 0.2rem (20%) */
            font-size: 0.68rem; /* Reducido de 0.85rem (20%) */
        }
        .mesa-body h6 {
            font-size: 0.72rem; /* Reducido de 0.9rem (20%) */
            margin: 0.4rem 0; /* Reducido de 0.5rem (20%) */
        }
        .mesa-footer {
            padding: 6.4px; /* Reducido de 8px (20%) */
            border-top: 0.8px solid #dee2e6; /* Reducido de 1px (20%) */
            text-align: center;
        }
        .estado-sin-atender {
            background-color: #f8d7da;
            border-color: #dc3545;
        }
        .estado-atendido {
            background-color: #d4edda;
            border-color: #28a745;
        }
        .estado-rechazado {
            background-color: #fff3cd;
            border-color: #ffc107;
        }
        .producto-table {
            margin-top: 4px; /* Reducido de 5px (20%) */
            font-size: 0.64rem; /* Reducido de 0.8rem (20%) */
        }
        .producto-table th, .producto-table td {
            vertical-align: middle;
            padding: 0.16rem 0.32rem; /* Reducido de 0.2rem 0.4rem (20%) */
        }
        .producto-table th {
            background-color: #f8f9fa;
            font-size: 0.64rem; /* Reducido de 0.8rem (20%) */
        }
        .producto-table td {
            font-size: 0.64rem; /* Reducido de 0.8rem (20%) */
        }
        .estado-pago {
            font-size: 0.6rem;
            font-weight: bold;
            margin-left: 4px;
        }
        .estado-pago.sin-pagar {
            color: #dc3545;
        }
        .estado-pago.pagado {
            color: #28a745;
        }
        hr {
            margin: 0.4rem 0; /* Reducido de 0.5rem (20%) */
        }
        .estado-verificado-btn {
            padding: 0.16rem; /* Reducido para que sea más pequeño */
            line-height: 1;
        }
    </style>
</head>
<body>
    <!-- Main Content -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-table me-2"></i> Gestión de Mesas</h2>

        <!-- Formulario para seleccionar fecha -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-calendar-alt me-2"></i> Seleccionar Fecha</h5>
            </div>
            <div class="card-body">
                <form method="GET" action="GestionMesas.php">
                    <div class="row g-2">
                        <div class="col-md-4">
                            <label for="fecha" class="form-label">Fecha:</label>
                            <input type="date" name="fecha" id="fecha" class="form-control" value="<?php echo htmlspecialchars($fecha); ?>" required>
                        </div>
                        <div class="col-md-2 align-self-end">
                            <button type="submit" class="btn btn-primary"><i class="fas fa-search me-2"></i> Filtrar</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <!-- Mostrar Mesas como Cuadros -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-chair me-2"></i> Mesas para el <?php echo htmlspecialchars($fecha); ?></h5>
            </div>
            <div class="card-body">
                <?php if (empty($mesas)): ?>
                    <p class="text-muted">No hay mesas para esta fecha.</p>
                <?php else: ?>
                    <div class="row row-cols-1 row-cols-md-3 g-4">
                        <?php foreach ($mesas as $mesa): ?>
                            <div class="col">
                                <div class="mesa-card <?php echo $mesa['estado_atencion'] === 'Atendido' ? 'estado-atendido' : ($mesa['estado_atencion'] === 'Rechazado' ? 'estado-rechazado' : 'estado-sin-atender'); ?>">
                                    <div class="mesa-header">
                                        <?php echo htmlspecialchars($mesa['nombreAgencia']); ?>
                                    </div>
                                    <div class="mesa-body">
                                        <p><strong>Fecha:</strong> <?php echo htmlspecialchars($mesa['fecha']); ?></p>
                                        <p><strong>Pasajeros:</strong> <?php echo htmlspecialchars($mesa['numero_pasajeros']); ?></p>
                                        <p><strong>Guía:</strong> <?php echo htmlspecialchars($mesa['nombreGuia']); ?></p>
                                        <p><strong>Estado:</strong> <?php echo htmlspecialchars($mesa['estado_atencion']); ?></p>

                                        <!-- Formulario para agregar producto -->
                                        <hr>
                                        <h6>Agregar Producto</h6>
                                        <form method="POST" action="GestionMesas.php">
                                            <input type="hidden" name="id_mesa" value="<?php echo $mesa['id_mesa']; ?>">
                                            <input type="hidden" name="fecha" value="<?php echo $fecha; ?>">
                                            <div class="row g-2 mb-2">
                                                <div class="col-md-5">
                                                    <select name="id_producto" class="form-select" required>
                                                        <option value="">Seleccionar producto</option>
                                                        <?php foreach ($productos as $producto): ?>
                                                            <option value="<?php echo $producto['id_productos']; ?>">
                                                                <?php echo htmlspecialchars($producto['nombreProdu']) . ' (S/ ' . $producto['precio_mercado'] . ')'; ?>
                                                            </option>
                                                        <?php endforeach; ?>
                                                    </select>
                                                </div>
                                                <div class="col-md-3">
                                                    <input type="number" name="cantidad" class="form-control" min="1" placeholder="Cantidad" required>
                                                </div>
                                                <div class="col-md-4">
                                                    <button type="submit" name="agregar_producto_mesa" class="btn btn-sm btn-success w-100"><i class="fas fa-plus"></i> Agregar</button>
                                                </div>
                                            </div>
                                        </form>

                                        <!-- Tabla de productos consumidos -->
                                        <hr>
                                        <h6>Productos Consumidos</h6>
                                        <?php if (empty($mesa['productos'])): ?>
                                            <p class="text-muted">No hay productos registrados.</p>
                                        <?php else: ?>
                                            <div class="producto-table">
                                                <table class="table table-bordered">
                                                    <thead>
                                                        <tr>
                                                            <th>Producto</th>
                                                            <th>Cant.</th>
                                                            <th>Costo Total</th>
                                                            <th></th>
                                                        </tr>
                                                    </thead>
                                                    <tbody>
                                                        <?php foreach ($mesa['productos'] as $producto): ?>
                                                            <tr>
                                                                <td><?php echo htmlspecialchars($producto['nombreProdu']); ?></td>
                                                                <td><?php echo htmlspecialchars($producto['cantidad']); ?></td>
                                                                <td>
                                                                    S/ <?php echo number_format($producto['costo_total'], 2); ?>
                                                                    <span class="estado-pago <?php echo $producto['estado_pago'] === 'pagado' ? 'pagado' : 'sin-pagar'; ?>">
                                                                        (<?php echo htmlspecialchars(ucfirst($producto['estado_pago'])); ?>)
                                                                    </span>
                                                                </td>
                                                                <td>
                                                                    <button type="button" class="btn btn-sm btn-primary estado-verificado-btn"
                                                                            data-id-mesa-producto="<?php echo $producto['id_mesa_producto']; ?>"
                                                                            data-estado-pago="<?php echo $producto['estado_pago']; ?>"
                                                                            data-check-verificado="<?php echo $producto['check_verificado'] ? 'true' : 'false'; ?>"
                                                                            data-bs-toggle="modal" data-bs-target="#estadoPagoModal">
                                                                        <i class="fas fa-calendar-alt"></i>
                                                                    </button>
                                                                    <a href="GestionMesas.php?action=imprimir&id_mesa_producto=<?php echo $producto['id_mesa_producto']; ?>&fecha=<?php echo urlencode($fecha); ?>" class="btn btn-sm btn-danger" style="margin-left: 4px;" target="_blank">
                                                                        <i class="fas fa-file-pdf"></i>
                                                                    </a>
                                                                </td>
                                                            </tr>
                                                        <?php endforeach; ?>
                                                    </tbody>
                                                </table>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                    <div class="mesa-footer">
                                        <form method="POST" action="GestionMesas.php">
                                            <input type="hidden" name="id_mesa" value="<?php echo $mesa['id_mesa']; ?>">
                                            <input type="hidden" name="fecha" value="<?php echo $fecha; ?>">
                                            <div class="d-flex justify-content-center align-items-center">
                                                <select name="estado_atencion" class="form-select w-auto me-2">
                                                    <option value="Sin atender" <?php echo $mesa['estado_atencion'] === 'Sin atender' ? 'selected' : ''; ?>>Sin atender</option>
                                                    <option value="Atendido" <?php echo $mesa['estado_atencion'] === 'Atendido' ? 'selected' : ''; ?>>Atendido</option>
                                                    <option value="Rechazado" <?php echo $mesa['estado_atencion'] === 'Rechazado' ? 'selected' : ''; ?>>Rechazado</option>
                                                </select>
                                                <button type="submit" name="actualizar_estado_mesa" class="btn btn-sm btn-primary"><i class="fas fa-save"></i> Actualizar</button>
                                            </div>
                                        </form>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <!-- Modal Único para Actualizar Estado de Pago -->
        <div class="modal fade" id="estadoPagoModal" tabindex="-1" aria-labelledby="estadoPagoModalLabel" aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="estadoPagoModalLabel">Actualizar Estado de Pago</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <form method="POST" action="GestionMesas.php" id="estadoPagoForm">
                            <input type="hidden" name="id_mesa_producto" id="modal_id_mesa_producto">
                            <input type="hidden" name="fecha" value="<?php echo htmlspecialchars($fecha); ?>">
                            <div class="mb-3">
                                <label for="modal_estado_pago" class="form-label">Estado de Pago</label>
                                <select name="estado_pago" id="modal_estado_pago" class="form-select">
                                    <option value="sin pagar">Sin pagar</option>
                                    <option value="pagado">Pagado</option>
                                </select>
                            </div>
                            <div class="mb-3 form-check">
                                <input type="checkbox" name="check_verificado" class="form-check-input" id="modal_check_verificado">
                                <label class="form-check-label" for="modal_check_verificado">Verificado</label>
                            </div>
                            <button type="submit" name="actualizar_estado_pago" class="btn btn-primary"><i class="fas fa-save"></i> Guardar</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='GestionMesas.php?fecha=<?php echo urlencode($fecha); ?>';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='GestionMesas.php?fecha=<?php echo urlencode($fecha); ?>';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='GestionMesas.php?fecha=<?php echo urlencode($fecha); ?>';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='GestionMesas.php?fecha=<?php echo urlencode($fecha); ?>';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Script para manejar el modal de estado de pago
        document.addEventListener('DOMContentLoaded', function () {
            const buttons = document.querySelectorAll('.estado-verificado-btn');
            buttons.forEach(button => {
                button.addEventListener('click', function () {
                    const idMesaProducto = this.getAttribute('data-id-mesa-producto');
                    const estadoPago = this.getAttribute('data-estado-pago');
                    const checkVerificado = this.getAttribute('data-check-verificado') === 'true';

                    // Actualizar los valores del modal
                    document.getElementById('modal_id_mesa_producto').value = idMesaProducto;
                    document.getElementById('modal_estado_pago').value = estadoPago;
                    document.getElementById('modal_check_verificado').checked = checkVerificado;
                });
            });
        });
    </script>
</body>
</html>