<?php
// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/MesaController.php';

// Incluir la librería FPDF
require_once '../../libs/fpdf/fpdf.php';

// Crear una instancia del controlador
$controller = new MesaController($pdo);

// Obtener el id_mesa_producto desde los parámetros GET
$id_mesa_producto = $_GET['id_mesa_producto'] ?? null;
$fecha = $_GET['fecha'] ?? date('Y-m-d');

if (!$id_mesa_producto) {
    die("Error: No se especificó un producto (id_mesa_producto no proporcionado).");
}

// Depuración: Verificar el id_mesa_producto recibido
error_log("ID Mesa Producto recibido: " . $id_mesa_producto);

// Obtener los datos de las mesas para la fecha
$data = $controller->listarMesas($fecha);
$mesas = $data['mesas'];

// Depuración: Verificar las mesas obtenidas
error_log("Mesas obtenidas: " . print_r($mesas, true));

// Buscar el producto específico dentro de las mesas
$producto_encontrado = null;
$agencia = '';
$fecha_mesa = $fecha;

foreach ($mesas as $mesa) {
    if (!empty($mesa['productos'])) {
        foreach ($mesa['productos'] as $producto) {
            if ($producto['id_mesa_producto'] == $id_mesa_producto) {
                $producto_encontrado = $producto;
                $agencia = $mesa['nombreAgencia'];
                $fecha_mesa = $mesa['fecha'];
                break 2; // Salir de ambos bucles
            }
        }
    }
}

if (!$producto_encontrado) {
    die("Error: Producto no encontrado para id_mesa_producto: " . htmlspecialchars($id_mesa_producto));
}

// Depuración: Verificar el producto encontrado
error_log("Producto encontrado: " . print_r($producto_encontrado, true));

// Generar el PDF
$pdf = new FPDF();
$pdf->AddPage();
$pdf->SetFont('Arial', 'B', 14);

// Encabezado del PDF
$pdf->Cell(0, 10, 'Ticket de Consumo - ' . $agencia, 0, 1, 'C');
$pdf->SetFont('Arial', '', 10);
$pdf->Cell(0, 8, 'Fecha: ' . date('d/m/Y', strtotime($fecha_mesa)), 0, 1, 'C');
$pdf->Cell(0, 8, 'Hora: ' . date('H:i:s'), 0, 1, 'C');
$pdf->Ln(5);

// Tabla con un solo producto
$pdf->SetFont('Arial', 'B', 10);
$pdf->SetFillColor(200, 220, 255);
$pdf->Cell(50, 8, 'Producto', 1, 0, 'C', true);
$pdf->Cell(20, 8, 'Cant.', 1, 0, 'C', true);
$pdf->Cell(30, 8, 'Costo Total', 1, 1, 'C', true);

$pdf->SetFont('Arial', '', 10);
$pdf->Cell(50, 8, $producto_encontrado['nombreProdu'], 1);
$pdf->Cell(20, 8, $producto_encontrado['cantidad'], 1, 0, 'C');
$pdf->Cell(30, 8, 'S/ ' . number_format($producto_encontrado['costo_total'], 2), 1, 1, 'R');

// Total (para este producto)
$pdf->SetFont('Arial', 'B', 11);
$pdf->Ln(5);
$pdf->Cell(50, 8, 'Total:', 0, 0, 'R');
$pdf->Cell(50, 8, 'S/ ' . number_format($producto_encontrado['costo_total'], 2), 0, 1, 'R');

// Salida del PDF (mostrar en el navegador)
$filename = 'Ticket_Consumo_' . $agencia . '_' . str_replace(' ', '_', $producto_encontrado['nombreProdu']) . '_' . date('Ymd_His') . '.pdf';
$pdf->Output('I', $filename);
exit();
?>