<?php
// Incluir la utilidad de autenticación
require_once '../config/auth.php';

// Verificar si el usuario está autenticado
requireLogin();

// Incluir configuración
require_once '../config/config.php';

// Incluir controlador y servicio
require_once '../controllers/ReservaController.php';
require_once '../services/EstadisticasService.php';

// Crear una instancia del controlador
$controller = new ReservaController($pdo);

// Obtener parámetros de filtro
$fechaInicio = isset($_GET['fecha_inicio']) ? trim($_GET['fecha_inicio']) : null;
$fechaFin = isset($_GET['fecha_fin']) ? trim($_GET['fecha_fin']) : null;
$idGuiaFiltro = isset($_GET['id_guia']) ? intval($_GET['id_guia']) : null;
$idAgenciaFiltro = isset($_GET['id_agencia']) ? intval($_GET['id_agencia']) : null;

// Validar el rango de fechas
if ($fechaInicio && $fechaFin && strtotime($fechaInicio) > strtotime($fechaFin)) {
    $temp = $fechaInicio;
    $fechaInicio = $fechaFin;
    $fechaFin = $temp;
}

// Obtener todas las reservaciones con filtros aplicados
$data = $controller->listarReservasConRelaciones($fechaInicio, $fechaFin, $idGuiaFiltro, $idAgenciaFiltro);
$reservas = $data['reservas'];
$guias = $data['guias'];
$agencias = $data['agencias'];

// Calcular estadísticas usando el servicio
$estadisticasService = new EstadisticasService($reservas);
$generales = $estadisticasService->calcularEstadisticasGenerales();
$porEstado = $estadisticasService->calcularEstadisticasPorEstado();
$porMes = $estadisticasService->calcularEstadisticasPorMes();
$porGuia = $estadisticasService->calcularReservasPorGuia();
$porAgencia = $estadisticasService->calcularReservasPorAgencia();
$metodosPago = $estadisticasService->calcularMetodosPago();

// Exportar a CSV si se solicita
if (isset($_GET['export']) && $_GET['export'] === 'csv') {
    $estadisticasService->exportarACSV();
}

// Preparar datos para JavaScript
$estadisticasJS = [
    'estados' => [
        'pagado' => $porEstado['estados']['pagado'],
        'sinPagar' => $porEstado['estados']['sin pagar']
    ],
    'metodosPago' => $metodosPago,
    'reservasPorMes' => $porMes['reservasPorMes'],
    'ingresosPorMesPagado' => $porMes['ingresosPorMesPagado'],
    'ingresosPorMesSinPagar' => $porMes['ingresosPorMesSinPagar'],
    'reservasPorGuia' => $porGuia,
    'reservasPorAgencia' => $porAgencia
];
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Estadísticas de Reservaciones - Terraza Andina</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Ajustar la ruta del CSS -->
    <link rel="stylesheet" href="../public/css/principal.css">
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
</head>
<body>
    <?php include 'templates/header.php'; ?>

    <main class="content">
        <h1 class="mb-4">Estadísticas de Reservaciones</h1>

        <!-- Formulario de filtros -->
        <section class="filter-form">
            <form method="GET" class="row g-3">
                <div class="col-md-3">
                    <label for="fecha_inicio" class="form-label">Fecha Inicio:</label>
                    <input type="date" name="fecha_inicio" id="fecha_inicio" class="form-control" value="<?php echo htmlspecialchars($fechaInicio ?? ''); ?>">
                </div>
                <div class="col-md-3">
                    <label for="fecha_fin" class="form-label">Fecha Fin:</label>
                    <input type="date" name="fecha_fin" id="fecha_fin" class="form-control" value="<?php echo htmlspecialchars($fechaFin ?? ''); ?>">
                </div>
                <div class="col-md-2">
                    <label for="id_guia" class="form-label">Guía:</label>
                    <select name="id_guia" id="id_guia" class="form-select">
                        <option value="">Todos</option>
                        <?php foreach ($guias as $guia): ?>
                            <option value="<?php echo $guia['id_guia']; ?>" <?php echo $idGuiaFiltro == $guia['id_guia'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($guia['nombreGuia']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label for="id_agencia" class="form-label">Agencia:</label>
                    <select name="id_agencia" id="id_agencia" class="form-select">
                        <option value="">Todas</option>
                        <?php foreach ($agencias as $agencia): ?>
                            <option value="<?php echo $agencia['id_agencia']; ?>" <?php echo $idAgenciaFiltro == $agencia['id_agencia'] ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($agencia['nombreAgencia']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2 align-self-end">
                    <button type="submit" class="btn btn-primary btn-sm">Filtrar</button>
                    <a href="<?php echo BASE_URL; ?>principal.php" class="btn btn-secondary btn-sm">Limpiar</a>
                </div>
            </form>
        </section>



        <!-- Estadísticas generales -->
        <section class="row">
            <div class="col-md-3">
                <div class="stats-card">
                    <i class="fas fa-ticket-alt"></i>
                    <h3>Total de Reservaciones</h3>
                    <p><?php echo $generales['totalReservas']; ?></p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <i class="fas fa-users"></i>
                    <h3>Total de Pasajeros</h3>
                    <p><?php echo $generales['totalPasajeros']; ?></p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <i class="fas fa-dollar-sign"></i>
                    <h3>Ingresos Totales</h3>
                    <p>$<?php echo number_format($generales['totalIngresos'], 2); ?></p>
                </div>
            </div>
            <div class="col-md-3">
                <div class="stats-card">
                    <i class="fas fa-user-friends"></i>
                    <h3>Promedio de Pasajeros</h3>
                    <p><?php echo number_format($generales['promedioPasajeros'], 1); ?></p>
                </div>
            </div>
        </section>

        <!-- Gráficos -->
        <section class="row">
            <div class="col-md-4">
                <div class="chart-container">
                    <h3>Reservaciones por Estado</h3>
                    <canvas id="estadoChart"></canvas>
                </div>
            </div>
            <div class="col-md-4">
                <div class="chart-container">
                    <h3>Métodos de Pago</h3>
                    <canvas id="metodoPagoChart"></canvas>
                </div>
            </div>
            <div class="col-md-4">
                <div class="chart-container">
                    <h3>Reservaciones por Mes</h3>
                    <canvas id="mesChart"></canvas>
                </div>
            </div>
        </section>

        <section class="row">
            <div class="col-md-6">
                <div class="chart-container">
                    <h3>Ingresos por Mes</h3>
                    <canvas id="ingresosMesChart"></canvas>
                </div>
            </div>
            <div class="col-md-6">
                <div class="chart-container">
                    <h3>Reservaciones por Guía</h3>
                    <canvas id="guiaChart"></canvas>
                </div>
            </div>
        </section>

        <section class="row">
            <div class="col-md-6">
                <div class="chart-container">
                    <h3>Reservaciones por Agencia</h3>
                    <canvas id="agenciaChart"></canvas>
                </div>
            </div>
        </section>
    </main>

    <?php include 'templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        window.estadisticas = <?php echo json_encode($estadisticasJS); ?>;
    </script>
    <!-- Ajustar la ruta del JavaScript -->
    <script src="../public/js/principal.js"></script>
</body>
</html>