<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../config/config.php';

// Incluir controlador
require_once '../controllers/ProductoController.php';

// Crear una instancia del controlador
$controller = new ProductoController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_producto"])) {
        $controller->agregarProducto();
    }
    if (isset($_POST["editar_producto"])) {
        $controller->editarProducto();
    }
    if (isset($_POST["eliminar_producto"])) {
        $controller->eliminarProducto();
    }
}

// Obtener la lista de productos para mostrar
$productos = $controller->listarProductos();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Productos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="content">
        <h2>Gestión de Productos</h2>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar un nuevo producto -->
        <form action="producto.php" method="POST" class="row g-3 mb-3">
            <div class="col-md-3">
                <label for="nombreProdu" class="form-label">Nombre:</label>
                <input type="text" name="nombreProdu" id="nombreProdu" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="cantidad" class="form-label">Cantidad:</label>
                <input type="number" name="cantidad" id="cantidad" class="form-control" required>
            </div>
            <div class="col-md-3">
                <label for="fecha_pedido" class="form-label">Fecha Pedido:</label>
                <input type="date" name="fecha_pedido" id="fecha_pedido" class="form-control" required>
            </div>
            <div class="col-md-2 align-self-end">
                <button type="submit" name="agregar_producto" class="btn btn-primary">Agregar</button>
            </div>
        </form>

        <h3>Lista de Productos</h3>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Cantidad</th>
                    <th>Fecha Pedido</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($productos as $producto): ?>
                <tr>
                    <td><?php echo htmlspecialchars($producto["id_productos"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["nombreProdu"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["cantidad"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["fecha_pedido"]); ?></td>
                    <td>
                        <!-- Formulario para editar producto -->
                        <form action="producto.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_productos" value="<?php echo $producto["id_productos"]; ?>">
                            <input type="text" name="nombreProdu" value="<?php echo htmlspecialchars($producto["nombreProdu"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 100px;">
                            <input type="number" name="cantidad" value="<?php echo htmlspecialchars($producto["cantidad"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 80px;">
                            <input type="date" name="fecha_pedido" value="<?php echo htmlspecialchars($producto["fecha_pedido"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 120px;">
                            <button type="submit" name="editar_producto" class="btn btn-warning btn-sm">Actualizar</button>
                        </form>
                        <!-- Formulario para eliminar producto -->
                        <form action="producto.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_productos" value="<?php echo $producto["id_productos"]; ?>">
                            <button type="submit" name="eliminar_producto" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar este producto?')">Eliminar</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>