<?php include '../templates/header.php';

// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/ListadoMercadoController.php';

// Crear una instancia del controlador
$controller = new ListadoMercadoController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["crear_lista"])) {
        $controller->crearListaMercado();
    }
    if (isset($_POST["agregar_producto_lista"])) {
        $controller->agregarProductoLista();
    }
    if (isset($_POST["eliminar_producto_lista"])) {
        $controller->eliminarProductoLista();
    }
    if (isset($_POST["seleccionar_lista"])) {
        $idListaSeleccionada = intval($_POST["id_lista_mercado"]);
    }
}

// Obtener datos para mostrar
$productos = $controller->listarProductos();
$listados = $controller->listarListadosMercado();
$detallesLista = isset($idListaSeleccionada) ? $controller->listarDetallesLista($idListaSeleccionada) : [];

// Manejar mensajes de éxito o error desde las redirecciones
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Lista de Mercado</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <!-- Incluir DataTables para una tabla interactiva -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 20px;
        }
        .card {
            border-radius: 10px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            margin-bottom: 15px;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 10px 10px 0 0;
            padding: 10px 15px;
        }
        .card-body {
            padding: 15px;
        }
        .form-control, .form-select {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.75rem;
        }
        .table th {
            background-color: #e9ecef;
            font-weight: 600;
        }
        .table td {
            vertical-align: middle;
            font-size: 0.9rem;
        }
        .price-highlight {
            font-weight: 500;
            color: #28a745;
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
    </style>
</head>
<body>
    <!-- Main Content -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-shopping-cart me-2"></i> Lista de Mercado</h2>

        <!-- Sección combinada: Crear Nuevo Listado y Gestionar Listado -->
        <div class="row g-3 mb-3">
            <!-- Crear Nuevo Listado -->
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0"><i class="fas fa-plus-circle me-2"></i> Crear Nuevo Listado</h5>
                    </div>
                    <div class="card-body">
                        <form action="ListadoMercado.php" method="POST" class="row g-2">
                            <div class="col-md-5">
                                <label for="fecha_lista" class="form-label">Fecha del Listado:</label>
                                <input type="date" name="fecha_lista" id="fecha_lista" class="form-control" required value="<?php echo date('Y-m-d'); ?>">
                            </div>
                            <div class="col-md-7">
                                <label for="descripcion" class="form-label">Descripción:</label>
                                <input type="text" name="descripcion" id="descripcion" class="form-control" placeholder="Ej. Listado para evento de abril">
                            </div>
                            <div class="col-md-12 mt-2">
                                <button type="submit" name="crear_lista" class="btn btn-primary"><i class="fas fa-save me-2"></i> Crear Listado</button>
                                <button type="reset" class="btn btn-secondary"><i class="fas fa-undo me-2"></i> Limpiar</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <!-- Gestionar Listado (Seleccionar y Agregar Productos) -->
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header">
                        <h5 class="mb-0"><i class="fas fa-list-alt me-2"></i> Gestionar Listado</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-2">
                            <!-- Seleccionar un listado existente -->
                            <div class="col-md-12">
                                <form action="ListadoMercado.php" method="POST">
                                    <label for="id_lista_mercado" class="form-label">Seleccionar Listado:</label>
                                    <select name="id_lista_mercado" id="id_lista_mercado" class="form-control" onchange="this.form.submit()">
                                        <option value="">Selecciona un listado</option>
                                        <?php foreach ($listados as $listado): ?>
                                            <option value="<?php echo $listado['id_lista_mercado']; ?>" <?php if (isset($idListaSeleccionada) && $idListaSeleccionada == $listado['id_lista_mercado']) echo 'selected'; ?>>
                                                <?php echo htmlspecialchars($listado['fecha_lista'] . ' - ' . ($listado['descripcion'] ?? 'Sin descripción')); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                    <input type="hidden" name="seleccionar_lista" value="1">
                                </form>
                            </div>

                            <!-- Formulario para agregar productos al listado -->
                            <?php if (isset($idListaSeleccionada)): ?>
                                <div class="col-md-12 mt-2">
                                    <form action="ListadoMercado.php" method="POST" class="row g-2">
                                        <input type="hidden" name="id_lista_mercado" value="<?php echo $idListaSeleccionada; ?>">
                                        <div class="col-md-6">
                                            <label for="id_productos" class="form-label">Producto:</label>
                                            <select name="id_productos" id="id_productos" class="form-control" required>
                                                <option value="">Selecciona un producto</option>
                                                <?php foreach ($productos as $producto): ?>
                                                    <option value="<?php echo $producto['id_productos']; ?>">
                                                        <?php 
                                                        echo htmlspecialchars(
                                                            $producto['nombreProdu'] . 
                                                            ' (' . ($producto['categoria'] ?? 'N/A') . 
                                                            ', Precio Mercado: S/ ' . number_format($producto['precio_mercado'] ?? 0, 2) . 
                                                            ', Unidad: ' . ($producto['unidad'] ?? 'N/A') . ')'
                                                        ); 
                                                        ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                        <div class="col-md-3">
                                            <label for="cantidad_solicitada" class="form-label">Cantidad:</label>
                                            <input type="number" name="cantidad_solicitada" id="cantidad_solicitada" class="form-control" required min="1">
                                        </div>
                                        <div class="col-md-3 align-self-end">
                                            <button type="submit" name="agregar_producto_lista" class="btn btn-success"><i class="fas fa-plus me-2"></i> Agregar</button>
                                        </div>
                                    </form>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Mostrar los productos en el listado seleccionado -->
        <?php if (isset($idListaSeleccionada)): ?>
            <div class="card">
                <div class="card-header">
                    <h5 class="mb-0"><i class="fas fa-table me-2"></i> Productos en el Listado</h5>
                </div>
                <div class="card-body">
                    <table id="productosTable" class="table table-striped">
                        <thead>
                            <tr>
                                <th>Producto</th>
                                <th>Categoría</th>
                                <th>Unidad</th>
                                <th>Cantidad Solicitada</th>
                                <th>Precio Abarrote</th>
                                <th>Precio Mercado</th>
                                <th>Precio Referencial</th>
                                <th>Costo Total (Mercado)</th>
                                <th>Acciones</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php 
                            $totalCostoMercado = 0;
                            foreach ($detallesLista as $detalle): 
                                $costoTotalProducto = $detalle['cantidad_solicitada'] * $detalle['precio_mercado'];
                                $totalCostoMercado += $costoTotalProducto;
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($detalle['nombreProdu']); ?></td>
                                    <td><?php echo htmlspecialchars($detalle['categoria'] ?? 'N/A'); ?></td>
                                    <td><?php echo htmlspecialchars($detalle['unidad'] ?? 'N/A'); ?></td>
                                    <td><?php echo htmlspecialchars($detalle['cantidad_solicitada']); ?></td>
                                    <td class="price-highlight">S/ <?php echo number_format($detalle['precio_abarrote'], 2); ?></td>
                                    <td class="price-highlight">S/ <?php echo number_format($detalle['precio_mercado'], 2); ?></td>
                                    <td class="price-highlight">S/ <?php echo number_format($detalle['precio_referencial'], 2); ?></td>
                                    <td class="price-highlight">S/ <?php echo number_format($costoTotalProducto, 2); ?></td>
                                    <td>
                                        <form action="ListadoMercado.php" method="POST" style="display:inline;">
                                            <input type="hidden" name="id_lista_mercado_detalle" value="<?php echo $detalle['id_lista_mercado_detalle']; ?>">
                                            <input type="hidden" name="id_lista_mercado" value="<?php echo $idListaSeleccionada; ?>">
                                            <button type="submit" name="eliminar_producto_lista" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar este producto del listado?')">
                                                <i class="fas fa-trash-alt"></i> Eliminar
                                            </button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <th colspan="7" class="text-end">Total (Mercado):</th>
                                <th>S/ <?php echo number_format($totalCostoMercado, 2); ?></th>
                                <th></th>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListadoMercado.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='ListadoMercado.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='ListadoMercado.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='ListadoMercado.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Incluir jQuery y DataTables -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#productosTable').DataTable({
                "language": {
                    "url": "//cdn.datatables.net/plug-ins/1.13.6/i18n/es-ES.json"
                },
                "pageLength": 10,
                "order": [[0, "asc"]]
            });
        });
    </script>
</body>
</html>