<?php
require_once '../../config/auth.php';
require_once '../../config/config.php';
require_once '../../controllers/ListadoMercadoController.php';

requireLogin();
$listaMercadoController = new ListadoMercadoController($pdo);

// Manejar la actualización del precio referencial en un listado específico (AJAX)
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["actualizar_precio_referencial_listado"])) {
    $response = $listaMercadoController->actualizarPrecioReferencialEnListado();
    header('Content-Type: application/json');
    echo json_encode($response);
    exit();
}

$id_lista_mercado = $_GET['id'] ?? null;
if (!$id_lista_mercado) {
    header("Location: ListaRapidaMercado.php?error=ID de lista no especificado.");
    exit();
}

$lista = $listaMercadoController->listarListadosMercado()[array_search($id_lista_mercado, array_column($listaMercadoController->listarListadosMercado(), 'id_lista_mercado'))];
$detalles = $listaMercadoController->listarDetallesLista($id_lista_mercado);

// Calcular el "Precio Ajustado Total" basado en los precios referenciales actuales
$precio_ajustado_total = 0;
foreach ($detalles as $detalle) {
    $precio_ajustado_total += $detalle['precio_referencial'] * $detalle['cantidad_solicitada'];
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Detalles de la Lista de Mercado #<?php echo htmlspecialchars($id_lista_mercado); ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <style>
        .content { max-width: 1200px; margin: 20px auto; padding: 20px; }
        .precio-referencial-listado-input {
            width: 100px;
            text-align: right;
        }
        .saving-indicator {
            display: none;
            color: #28a745;
            font-size: 0.85rem;
            margin-left: 5px;
        }
        .diferencia-negativa {
            color: #dc3545; /* Rojo para diferencias negativas */
        }
        .diferencia-positiva {
            color: #28a745; /* Verde para diferencias positivas */
        }
    </style>
</head>
<body>
<?php include '../templates/header.php'; ?>
    <div class="content">
        <h2>Detalles de la Lista de Mercado #<?php echo htmlspecialchars($id_lista_mercado); ?></h2>
        <div class="card">
            <div class="card-header">
                <h5>Información General</h5>
            </div>
            <div class="card-body">
                <p><strong>Fecha:</strong> <?php echo htmlspecialchars(date('d/m/Y', strtotime($lista['fecha_lista']))); ?></p>
                <p><strong>Total General:</strong> S/ <?php echo number_format($lista['total_general'], 2); ?></p>
                <p><strong>Precio Ajustado Total:</strong> S/ <?php echo number_format($precio_ajustado_total, 2); ?></p>
            </div>
        </div>
        <div class="card mt-3">
            <div class="card-header">
                <h5>Detalles de Productos</h5>
            </div>
            <div class="card-body">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>Producto</th>
                            <th>Categoría</th>
                            <th>Unidad</th>
                            <th>Cantidad</th>
                            <th>Precio Mercado</th>
                            <th>Precio Referencial</th>
                            <th>Costo Total</th>
                            <th>Total Actualizado</th>
                            <th>Diferencia</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($detalles as $detalle): ?>
                            <?php
                            // Calcular el costo total basado en el precio de mercado
                            $costo_total_mercado = $detalle['precio_mercado'] * $detalle['cantidad_solicitada'];
                            // Calcular el costo total basado en el precio referencial (Total Actualizado)
                            $total_actualizado = $detalle['precio_referencial'] * $detalle['cantidad_solicitada'];
                            // Calcular la diferencia (Costo Total - Total Actualizado)
                            $diferencia = $costo_total_mercado - $total_actualizado;
                            // Determinar la clase CSS para la diferencia
                            $diferencia_clase = $diferencia < 0 ? 'diferencia-negativa' : 'diferencia-positiva';
                            ?>
                            <tr>
                                <td><?php echo htmlspecialchars($detalle['nombre_producto']); ?></td>
                                <td><?php echo htmlspecialchars($detalle['categoria']); ?></td>
                                <td><?php echo htmlspecialchars($detalle['unidad']); ?></td>
                                <td><?php echo htmlspecialchars($detalle['cantidad_solicitada']); ?></td>
                                <td>S/ <?php echo number_format($detalle['precio_mercado'], 2); ?></td>
                                <td>
                                    <div class="d-flex align-items-center">
                                        <input type="number" step="0.01" class="form-control precio-referencial-listado-input" 
                                               value="<?php echo number_format($detalle['precio_referencial'], 2); ?>" 
                                               data-id-detalle="<?php echo $detalle['id_lista_mercado_detalle']; ?>">
                                        <span class="saving-indicator">Guardando...</span>
                                    </div>
                                </td>
                                <td>S/ <?php echo number_format($costo_total_mercado, 2); ?></td>
                                <td>S/ <?php echo number_format($total_actualizado, 2); ?></td>
                                <td class="<?php echo $diferencia_clase; ?>">
                                    S/ <?php echo number_format($diferencia, 2); ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <a href="ListaRapidaMercado.php" class="btn btn-secondary mt-3">Volver</a>
    </div>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $(document).ready(function() {
            let timeout = null;

            // Manejar la actualización del precio referencial en un listado específico
            $('.precio-referencial-listado-input').on('input', function() {
                var $input = $(this);
                var $indicator = $input.siblings('.saving-indicator');
                var idDetalle = $input.data('id-detalle');
                var precioReferencial = parseFloat($input.val());

                // Mostrar el indicador de "Guardando..."
                $indicator.show();

                // Limpiar el temporizador anterior
                if (timeout) {
                    clearTimeout(timeout);
                }

                // Configurar un nuevo temporizador para guardar después de 1 segundo de inactividad
                timeout = setTimeout(function() {
                    if (isNaN(precioReferencial) || precioReferencial < 0) {
                        $indicator.hide();
                        $input.val($input.data('original-value'));
                        return;
                    }

                    $.ajax({
                        url: 'VerListaMercado.php?id=<?php echo $id_lista_mercado; ?>',
                        type: 'POST',
                        data: {
                            actualizar_precio_referencial_listado: true,
                            id_lista_mercado_detalle: idDetalle,
                            precio_referencial: precioReferencial
                        },
                        dataType: 'json',
                        success: function(response) {
                            if (response.success) {
                                $input.data('original-value', precioReferencial);
                                // Recargar la página para actualizar el Precio Ajustado Total y las nuevas columnas
                                window.location.reload();
                            } else {
                                $input.val($input.data('original-value'));
                            }
                            $indicator.hide();
                        },
                        error: function() {
                            $input.val($input.data('original-value'));
                            $indicator.hide();
                        }
                    });
                }, 1000); // Esperar 1 segundo después de que el usuario deje de escribir
            });

            // Guardar el valor original del precio referencial
            $('.precio-referencial-listado-input').each(function() {
                $(this).data('original-value', $(this).val());
            });
        });
    </script>
</body>
</html>