<?php
// Sección de verificación
require_once '../../config/auth.php';
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controladores
require_once '../../controllers/ListadoMercadoController.php';

// Crear instancias de los controladores
$controller = new ListadoMercadoController($pdo);

// Obtener todos los listados de mercado
$listas_mercado = $controller->listarListadosMercado();

// Manejar mensajes de éxito o error
$success = $_GET['success'] ?? '';
$error = $_GET['error'] ?? '';
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Listas de Mercado Guardadas</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="../public/css/sidebar.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.5.1/css/all.min.css" integrity="sha512-DTOQO9RWCH3ppGqcWaEA1BIZOC6xxalwEsw9c2QQeAIftl+Vegovlnee1c9QX4TctnWMn13TZye+giMm8e2LwA==" crossorigin="anonymous" referrerpolicy="no-referrer" />
    <!-- Incluir DataTables -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .content {
            max-width: 1400px;
            margin: 0 auto;
            padding: 20px;
        }
        .card {
            border-radius: 10px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            margin-bottom: 15px;
        }
        .card-header {
            background-color: #007bff;
            color: white;
            border-radius: 10px 10px 0 0;
            padding: 10px 15px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .card-body {
            padding: 15px;
        }
        .btn {
            border-radius: 5px;
            font-size: 0.9rem;
            padding: 0.25rem 0.75rem;
        }
        .table th, .table td {
            vertical-align: middle;
            font-size: 0.85rem;
            padding: 4px 8px;
        }
        .table th {
            background-color: #e9ecef;
            font-weight: 600;
        }
        .modal-backdrop { z-index: 1040 !important; }
        .modal { z-index: 1050 !important; }
    </style>
</head>
<body>
<?php include '../templates/header.php'; ?>
    <!-- Main Content -->
    <div class="content">
        <h2 class="mb-3"><i class="fas fa-history me-2"></i> Listas de Mercado Guardadas</h2>

        <!-- Sección para visualizar pedidos guardados -->
        <div class="card">
            <div class="card-header">
                <h5 class="mb-0"><i class="fas fa-list me-2"></i> Listados</h5>
            </div>
            <div class="card-body">
                <table id="listasMercadoTable" class="table table-striped">
                    <thead>
                        <tr>
                            <th>Lista</th>
                            <th>Fecha</th>
                            <th>Cantidad</th>
                            <th>Total General</th>
                            <th>Precio Ajustado Total</th>
                            <th>Acciones</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($listas_mercado as $lista): ?>
                            <tr>
                                <td>Lista #<?php echo htmlspecialchars($lista['id_lista_mercado']); ?></td>
                                <td><?php echo htmlspecialchars(date('d/m/Y', strtotime($lista['fecha_lista']))); ?></td>
                                <td><?php echo htmlspecialchars($lista['cantidad_total']); ?></td>
                                <td>S/ <?php echo number_format($lista['total_general'], 2); ?></td>
                                <td>S/ <?php echo number_format($lista['precio_ajustado_total'], 2); ?></td>
                                <td>
                                    <a href="VerListaMercado.php?id=<?php echo $lista['id_lista_mercado']; ?>" class="btn btn-info btn-sm"><i class="fas fa-eye"></i> Ver Lista</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Modal para Mensajes de Éxito -->
        <?php if ($success): ?>
            <div class="modal fade show" id="successModal" tabindex="-1" aria-labelledby="successModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="successModalLabel">Éxito</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='listaMercadoGuardadas.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($success); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-primary" data-bs-dismiss="modal" onclick="window.location.href='listaMercadoGuardadas.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>

        <!-- Modal para Mensajes de Error -->
        <?php if ($error): ?>
            <div class="modal fade show" id="errorModal" tabindex="-1" aria-labelledby="errorModalLabel" aria-hidden="true" style="display: block;">
                <div class="modal-dialog">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="errorModalLabel">Error</h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close" onclick="window.location.href='listaMercadoGuardadas.php';"></button>
                        </div>
                        <div class="modal-body">
                            <?php echo htmlspecialchars($error); ?>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-danger" data-bs-dismiss="modal" onclick="window.location.href='listaMercadoGuardadas.php';">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
            <div class="modal-backdrop fade show"></div>
        <?php endif; ?>
    </div>

    <!-- Scripts -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Incluir jQuery y DataTables -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
    <script>
        $(document).ready(function() {
            // Inicializar DataTables para listas de mercado
            $('#listasMercadoTable').DataTable({
                "language": {
                    "url": "//cdn.datatables.net/plug-ins/1.13.6/i18n/es-ES.json"
                },
                "pageLength": 10,
                "order": [[1, "desc"]] // Ordenar por la columna "Fecha" (índice 1)
            });
        });
    </script>
</body>
</html>