<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Verificar si el usuario está autenticado
require_once '../../config/auth.php';
requireLogin();

// Incluir configuración
require_once '../../config/config.php'; // Ajustado para subir dos niveles desde views/producto/

// Incluir controlador
require_once '../../controllers/ProductoController.php'; // Ajustado para subir dos niveles

// Crear una instancia del controlador
$controller = new ProductoController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_producto"])) {
        $controller->agregarProducto();
    }
    if (isset($_POST["eliminar_producto"])) {
        $controller->eliminarProducto();
    }
}

// Obtener la lista de productos para mostrar
$productos = $controller->listarProductos();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Productos</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 1200px; /* Aumentado para dar más espacio a las nuevas columnas */
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .table th, .table td {
            font-size: 0.9rem;
            vertical-align: middle;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Crear Producto</h1>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar un nuevo producto -->
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="agregar_producto" value="1">
            <div class="col-md-2">
                <label for="nombreProdu" class="form-label">Nombre:</label>
                <input type="text" name="nombreProdu" id="nombreProdu" class="form-control" required>
            </div>
            <div class="col-md-1">
                <label for="cantidad" class="form-label">Cantidad:</label>
                <input type="number" name="cantidad" id="cantidad" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="fecha_pedido" class="form-label">Fecha Pedido:</label>
                <input type="date" name="fecha_pedido" id="fecha_pedido" class="form-control" required>
            </div>
            <div class="col-md-1">
                <label for="unidad" class="form-label">Unidad:</label>
                <select name="unidad" id="unidad" class="form-select" required>
                    <option value="">Seleccione</option>
                    <option value="unidad">Unidad</option>
                    <option value="kg">kg</option>
                    <option value="litro">litro</option>
                </select>
            </div>
            <div class="col-md-1">
                <label for="precio_abarrote" class="form-label">Precio Abarrote:</label>
                <input type="number" step="0.01" name="precio_abarrote" id="precio_abarrote" class="form-control" required>
            </div>
            <div class="col-md-1">
                <label for="precio_mercado" class="form-label">Precio Mercado:</label>
                <input type="number" step="0.01" name="precio_mercado" id="precio_mercado" class="form-control" required>
            </div>
            <div class="col-md-1">
                <label for="precio_referencial" class="form-label">Precio Referencial:</label>
                <input type="number" step="0.01" name="precio_referencial" id="precio_referencial" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="categoria" class="form-label">Categoría:</label>
                <select name="categoria" id="categoria" class="form-select" required>
                    <option value="">Seleccione</option>
                    <option value="fruta">Fruta</option>
                    <option value="verdura">Verdura</option>
                    <option value="lácteos">Lácteos</option>
                    <option value="carnes">Carnes</option>
                    <!-- Agrega más categorías según la tabla productsdata -->
                </select>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Guardar</button>
            </div>
        </form>

        <h3>Lista de Productos</h3>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Cantidad</th>
                    <th>Fecha Pedido</th>
                    <th>Unidad</th>
                    <th>Precio Abarrote</th>
                    <th>Precio Mercado</th>
                    <th>Precio Referencial</th>
                    <th>Categoría</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($productos as $producto): ?>
                <tr>
                    <td><?php echo htmlspecialchars($producto["id_productos"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["nombreProdu"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["cantidad"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["fecha_pedido"]); ?></td>
                    <td><?php echo htmlspecialchars($producto["unidad"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($producto["precio_abarrote"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($producto["precio_mercado"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($producto["precio_referencial"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($producto["categoria"] ?? 'N/A'); ?></td>
                    <td>
                        <a href="productoedit.php?id=<?php echo $producto["id_productos"]; ?>" class="btn btn-warning btn-sm">Actualizar</a>
                        <form method="POST" style="display:inline;">
                            <input type="hidden" name="eliminar_producto" value="1">
                            <input type="hidden" name="id_productos" value="<?php echo $producto["id_productos"]; ?>">
                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar este producto?')">Eliminar</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>