<?php
// Verificar si el usuario está autenticado
require_once '../../config/auth.php';
requireLogin();

// productoedit.php
require_once '../../config/config.php';
require_once '../../controllers/ProductoController.php';

$controller = new ProductoController($pdo);

if (isset($_GET['id'])) {
    $id = intval($_GET['id']);
    $producto = $controller->listarProductos();
    $producto = array_filter($producto, fn($p) => $p['id_productos'] == $id);
    $producto = reset($producto);

    // Si el producto no existe, redirigir con un error
    if (!$producto) {
        header("Location: productocreate.php?error=Producto no encontrado.");
        exit();
    }
}

if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_producto"])) {
    $controller->editarProducto();
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Editar Producto</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .content {
            max-width: 1200px; /* Aumentado para dar más espacio a los nuevos campos */
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Editar Producto</h1>
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="editar_producto" value="1">
            <input type="hidden" name="id_productos" value="<?php echo htmlspecialchars($producto['id_productos']); ?>">
            <div class="col-md-2">
                <label for="nombreProdu" class="form-label">Nombre:</label>
                <input type="text" name="nombreProdu" id="nombreProdu" class="form-control" value="<?php echo htmlspecialchars($producto['nombreProdu']); ?>" required>
            </div>
            <div class="col-md-1">
                <label for="cantidad" class="form-label">Cantidad:</label>
                <input type="number" name="cantidad" id="cantidad" class="form-control" value="<?php echo htmlspecialchars($producto['cantidad']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="fecha_pedido" class="form-label">Fecha Pedido:</label>
                <input type="date" name="fecha_pedido" id="fecha_pedido" class="form-control" value="<?php echo htmlspecialchars($producto['fecha_pedido']); ?>" required>
            </div>
            <div class="col-md-1">
                <label for="unidad" class="form-label">Unidad:</label>
                <select name="unidad" id="unidad" class="form-select" required>
                    <option value="unidad" <?php echo ($producto['unidad'] == 'unidad') ? 'selected' : ''; ?>>Unidad</option>
                    <option value="kg" <?php echo ($producto['unidad'] == 'kg') ? 'selected' : ''; ?>>kg</option>
                    <option value="litro" <?php echo ($producto['unidad'] == 'litro') ? 'selected' : ''; ?>>litro</option>
                </select>
            </div>
            <div class="col-md-1">
                <label for="precio_abarrote" class="form-label">Precio Abarrote:</label>
                <input type="number" step="0.01" name="precio_abarrote" id="precio_abarrote" class="form-control" value="<?php echo htmlspecialchars($producto['precio_abarrote']); ?>" required>
            </div>
            <div class="col-md-1">
                <label for="precio_mercado" class="form-label">Precio Mercado:</label>
                <input type="number" step="0.01" name="precio_mercado" id="precio_mercado" class="form-control" value="<?php echo htmlspecialchars($producto['precio_mercado']); ?>" required>
            </div>
            <div class="col-md-1">
                <label for="precio_referencial" class="form-label">Precio Referencial:</label>
                <input type="number" step="0.01" name="precio_referencial" id="precio_referencial" class="form-control" value="<?php echo htmlspecialchars($producto['precio_referencial']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="categoria" class="form-label">Categoría:</label>
                <select name="categoria" id="categoria" class="form-select" required>
                    <option value="fruta" <?php echo ($producto['categoria'] == 'fruta') ? 'selected' : ''; ?>>Fruta</option>
                    <option value="verdura" <?php echo ($producto['categoria'] == 'verdura') ? 'selected' : ''; ?>>Verdura</option>
                    <option value="lácteos" <?php echo ($producto['categoria'] == 'lácteos') ? 'selected' : ''; ?>>Lácteos</option>
                    <option value="carnes" <?php echo ($producto['categoria'] == 'carnes') ? 'selected' : ''; ?>>Carnes</option>
                </select>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Guardar</button>
            </div>
        </form>
    </div>

    <?php include '../templates/footer.php'; ?>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>