<?php

// Incluir la utilidad de autenticación
require_once '../../config/auth.php';

// Verificar si el usuario está autenticado
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../config/config.php';

// Incluir controlador
require_once '../controllers/ReservaController.php';

// Crear una instancia del controlador
$controller = new ReservaController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_reserva"])) {
        $controller->agregarReserva();
    }
    if (isset($_POST["editar_reserva"])) {
        $controller->editarReserva();
    }
    if (isset($_POST["eliminar_reserva"])) {
        $controller->eliminarReserva();
    }
}

// Obtener la lista de reservas y datos relacionados para mostrar
$datos = $controller->listarReservasConRelaciones();
$reservas = $datos['reservas'];
$guias = $controller->listarGuias();
$agencias = $controller->listarAgencias();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Gestión de Reservas</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="content">
        <h2>Gestión de Reservas</h2>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar una nueva reserva -->
        <form action="reserva.php" method="POST" class="row g-3 mb-3">
            <div class="col-md-2">
                <label for="fecha_mes_y_año" class="form-label">Fecha:</label>
                <input type="date" name="fecha_mes_y_año" id="fecha_mes_y_año" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="id_guia" class="form-label">Guía:</label>
                <select name="id_guia" id="id_guia" class="form-control" required>
                    <option value="">Selecciona un guía</option>
                    <?php foreach ($guias as $guia): ?>
                        <option value="<?php echo $guia['id_guia']; ?>"><?php echo htmlspecialchars($guia['nombreGuia']); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-2">
                <label for="id_agencia" class="form-label">Agencia:</label>
                <select name="id_agencia" id="id_agencia" class="form-control" required>
                    <option value="">Selecciona una agencia</option>
                    <?php foreach ($agencias as $agencia): ?>
                        <option value="<?php echo $agencia['id_agencia']; ?>"><?php echo htmlspecialchars($agencia['nombreAgencia']); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-2">
                <label for="numero_pasajeros" class="form-label">Nro Pasajeros:</label>
                <input type="number" name="numero_pasajeros" id="numero_pasajeros" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="firma" class="form-label">Firma:</label>
                <input type="text" name="firma" id="firma" class="form-control">
            </div>
            <div class="col-md-2">
                <label for="observaciones" class="form-label">Observaciones:</label>
                <textarea name="observaciones" id="observaciones" class="form-control"></textarea>
            </div>
            <div class="col-md-2 align-self-end">
                <button type="submit" name="agregar_reserva" class="btn btn-primary">Agregar</button>
            </div>
        </form>

        <h3>Lista de Reservas</h3>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Fecha</th>
                    <th>Guía</th>
                    <th>Agencia</th>
                    <th>Nro Pasajeros</th>
                    <th>Firma</th>
                    <th>Observaciones</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($reservas as $reserva): ?>
                <tr>
                    <td><?php echo htmlspecialchars($reserva["id_reservaciongeneral"]); ?></td>
                    <td><?php echo htmlspecialchars($reserva["fecha_mes_y_año"]); ?></td>
                    <td><?php echo htmlspecialchars($reserva["nombreGuia"]); ?></td>
                    <td><?php echo htmlspecialchars($reserva["nombreAgencia"]); ?></td>
                    <td><?php echo htmlspecialchars($reserva["numero_pasajeros"]); ?></td>
                    <td><?php echo htmlspecialchars($reserva["firma"] ?? 'N/A'); ?></td>
                    <td><?php echo htmlspecialchars($reserva["observaciones"] ?? 'N/A'); ?></td>
                    <td>
                        <!-- Formulario para editar reserva -->
                        <form action="reserva.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_reservaciongeneral" value="<?php echo $reserva["id_reservaciongeneral"]; ?>">
                            <input type="date" name="fecha_mes_y_año" value="<?php echo htmlspecialchars($reserva["fecha_mes_y_año"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 120px;">
                            <select name="id_guia" class="form-control form-control-sm" required style="display:inline; width: 120px;">
                                <option value="">Selecciona un guía</option>
                                <?php foreach ($guias as $guia): ?>
                                    <option value="<?php echo $guia['id_guia']; ?>" <?php if ($guia['id_guia'] == $reserva['id_guia']) echo 'selected'; ?>><?php echo htmlspecialchars($guia['nombreGuia']); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <select name="id_agencia" class="form-control form-control-sm" required style="display:inline; width: 120px;">
                                <option value="">Selecciona una agencia</option>
                                <?php foreach ($agencias as $agencia): ?>
                                    <option value="<?php echo $agencia['id_agencia']; ?>" <?php if ($agencia['id_agencia'] == $reserva['id_agencia']) echo 'selected'; ?>><?php echo htmlspecialchars($agencia['nombreAgencia']); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <input type="number" name="numero_pasajeros" value="<?php echo htmlspecialchars($reserva["numero_pasajeros"]); ?>" class="form-control form-control-sm" required style="display:inline; width: 80px;">
                            <input type="text" name="firma" value="<?php echo htmlspecialchars($reserva["firma"] ?? ''); ?>" class="form-control form-control-sm" style="display:inline; width: 80px;">
                            <textarea name="observaciones" class="form-control form-control-sm" style="display:inline; width: 100px;"><?php echo htmlspecialchars($reserva["observaciones"] ?? ''); ?></textarea>
                            <button type="submit" name="editar_reserva" class="btn btn-warning btn-sm">Actualizar</button>
                        </form>
                        <!-- Formulario para eliminar reserva -->
                        <form action="reserva.php" method="POST" style="display:inline;">
                            <input type="hidden" name="id_reservaciongeneral" value="<?php echo $reserva["id_reservaciongeneral"]; ?>">
                            <button type="submit" name="eliminar_reserva" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta reserva?')">Eliminar</button>
                        </form>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>