<?php
// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

//inicio seccion
require_once '../../config/auth.php';
// Verificar si el usuario está autenticado
requireLogin();

// Incluir configuración
require_once '../../config/config.php';

// Incluir controladores
require_once '../../controllers/ReservaController.php';

// Crear instancias de los controladores
$controller = new ReservaController($pdo);

// Procesar solicitudes POST para acciones CRUD
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["agregar_reserva"])) {
        $controller->agregarReserva();
    }
    if (isset($_POST["eliminar_reserva"])) {
        $controller->eliminarReserva();
    }
}

// Obtener la lista de reservas, guías y agencias para mostrar
$data = $controller->listarReservasConRelaciones();
$reservas = $data['reservas'];
$guias = $data['guias'];
$agencias = $data['agencias'];
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Crear Reserva</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .table th, .table td {
            font-size: 0.9rem;
            vertical-align: middle;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Crear Reserva</h1>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para agregar una nueva reserva -->
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="agregar_reserva" value="1">
            <div class="col-md-2">
                <label for="fecha_mes_y_anio" class="form-label">Fecha (Mes y Año):</label>
                <input type="date" name="fecha_mes_y_anio" id="fecha_mes_y_anio" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="id_guia" class="form-label">Guía:</label>
                <select name="id_guia" id="id_guia" class="form-select" required>
                    <option value="">Seleccione</option>
                    <?php foreach ($guias as $guia): ?>
                        <option value="<?php echo $guia['id_guia']; ?>"><?php echo htmlspecialchars($guia['nombreGuia']); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-2">
                <label for="id_agencia" class="form-label">Agencia:</label>
                <select name="id_agencia" id="id_agencia" class="form-select" required>
                    <option value="">Seleccione</option>
                    <?php foreach ($agencias as $agencia): ?>
                        <option value="<?php echo $agencia['id_agencia']; ?>"><?php echo htmlspecialchars($agencia['nombreAgencia']); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-1">
                <label for="numero_pasajeros" class="form-label">Nº Pasajeros:</label>
                <input type="number" name="numero_pasajeros" id="numero_pasajeros" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="firma" class="form-label">Firma:</label>
                <input type="text" name="firma" id="firma" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="observaciones" class="form-label">Observaciones:</label>
                <textarea name="observaciones" id="observaciones" class="form-control"></textarea>
            </div>
            <div class="col-md-1">
                <label for="adelanto" class="form-label">Adelanto:</label>
                <input type="number" step="0.01" name="adelanto" id="adelanto" class="form-control" required>
            </div>
            <div class="col-md-2">
                <label for="metodo_pago" class="form-label">Método de Pago:</label>
                <select name="metodo_pago" id="metodo_pago" class="form-select" required>
                    <option value="">Seleccione</option>
                    <option value="Efectivo">Efectivo</option>
                    <option value="Tarjeta">Tarjeta</option>
                    <option value="Transferencia">Transferencia</option>
                </select>
            </div>
            <div class="col-md-2">
                <label for="estado" class="form-label">Estado:</label>
                <select name="estado" id="estado" class="form-select" required>
                    <option value="sin pagar">Sin Pagar</option>
                    <option value="pagado">Pagado</option>
                </select>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Guardar</button>
            </div>
        </form>

        <h3>Lista de Reservas</h3>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Fecha (Mes y Año)</th>
                    <th>Guía</th>
                    <th>Agencia (Precio)</th>
                    <th>Nº Pasajeros</th>
                    <th>Firma</th>
                    <th>Observaciones</th>
                    <th>Adelanto</th>
                    <th>Método de Pago</th>
                    <th>Totalidad</th>
                    <th>Estado</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($reservas)): ?>
                    <tr>
                        <td colspan="12" class="text-center">No hay reservas registradas.</td>
                    </tr>
                <?php else: ?>
                    <?php foreach ($reservas as $reserva): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($reserva["id_reservaciongeneral"]); ?></td>
                        <td><?php echo htmlspecialchars($reserva["fecha_mes_y_año"]); ?></td>
                        <td><?php echo htmlspecialchars($reserva["nombreGuia"]); ?></td>
                        <td>
                            <?php echo htmlspecialchars($reserva["nombreAgencia"]); ?>
                            (<?php echo htmlspecialchars($reserva["precio_agencia"] ?? 'N/A'); ?>)
                        </td>
                        <td><?php echo htmlspecialchars($reserva["numero_pasajeros"]); ?></td>
                        <td><?php echo htmlspecialchars($reserva["firma"]); ?></td>
                        <td><?php echo htmlspecialchars($reserva["observaciones"] ?? 'N/A'); ?></td>
                        <td><?php echo htmlspecialchars($reserva["adelanto"] ?? 'N/A'); ?></td>
                        <td><?php echo htmlspecialchars($reserva["metodo_pago"] ?? 'N/A'); ?></td>
                        <td><?php echo htmlspecialchars($reserva["totalidad"] ?? 'N/A'); ?></td>
                        <td><?php echo htmlspecialchars($reserva["estado"]); ?></td>
                        <td>
                            <a href="reservaedit.php?id=<?php echo $reserva["id_reservaciongeneral"]; ?>" class="btn btn-warning btn-sm">Actualizar</a>
                            <form method="POST" style="display:inline;">
                                <input type="hidden" name="eliminar_reserva" value="1">
                                <input type="hidden" name="id_reservaciongeneral" value="<?php echo $reserva["id_reservaciongeneral"]; ?>">
                                <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta reserva?')">Eliminar</button>
                            </form>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>