<?php
// Incluir la utilidad de autenticación
require_once '../../config/auth.php';

// Verificar si el usuario está autenticado
requireLogin();

// Habilitar la depuración para ver errores
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir configuración
require_once '../../config/config.php';

// Incluir controlador
require_once '../../controllers/ReservaController.php';

// Crear instancias de los controladores
$controller = new ReservaController($pdo);

// Obtener la reserva a editar
if (isset($_GET['id'])) {
    $id = intval($_GET['id']);
    $data = $controller->listarReservasConRelaciones();
    $reservas = $data['reservas'];
    $reserva = array_filter($reservas, fn($r) => $r['id_reservaciongeneral'] == $id);
    $reserva = reset($reserva);

    if (!$reserva) {
        header("Location: " . BASE_URL . "reserva/reservacreate.php?error=Reserva no encontrada.");
        exit();
    }
} else {
    header("Location: " . BASE_URL . "reserva/reservacreate.php?error=ID de reserva no especificado.");
    exit();
}

if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST["editar_reserva"])) {
    $controller->editarReserva();
}

// Obtener la lista de guías y agencias para los select
$guias = $data['guias'];
$agencias = $data['agencias'];
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Editar Reserva</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f8f9fa;
        }
        .content {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }
        .form-control, .form-select {
            font-size: 0.9rem;
            padding: 0.25rem 0.5rem;
        }
        .form-label {
            font-size: 0.9rem;
            margin-bottom: 0.25rem;
        }
        .btn-sm {
            font-size: 0.8rem;
            padding: 0.2rem 0.5rem;
        }
        footer {
            text-align: center;
            padding: 10px 0;
            background-color: #f8f9fa;
            position: fixed;
            bottom: 0;
            width: 100%;
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <h1>Editar Reserva</h1>

        <!-- Mostrar mensajes de éxito o error desde las redirecciones -->
        <?php
        $success = $_GET['success'] ?? '';
        $error = $_GET['error'] ?? '';
        if ($success): ?>
            <div class="alert alert-success"><?php echo htmlspecialchars($success); ?></div>
        <?php endif; ?>
        <?php if ($error): ?>
            <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
        <?php endif; ?>

        <!-- Formulario para editar una reserva -->
        <form method="POST" class="row g-2 mb-4">
            <input type="hidden" name="editar_reserva" value="1">
            <input type="hidden" name="id_reservaciongeneral" value="<?php echo $reserva['id_reservaciongeneral']; ?>">
            <div class="col-md-2">
                <label for="fecha_mes_y_anio" class="form-label">Fecha (Mes y Año):</label>
                <input type="date" name="fecha_mes_y_anio" id="fecha_mes_y_anio" class="form-control" value="<?php echo htmlspecialchars($reserva['fecha_mes_y_año']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="id_guia" class="form-label">Guía:</label>
                <select name="id_guia" id="id_guia" class="form-select" required>
                    <option value="">Seleccione</option>
                    <?php foreach ($guias as $guia): ?>
                        <option value="<?php echo $guia['id_guia']; ?>" <?php echo $guia['id_guia'] == $reserva['id_guia'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($guia['nombreGuia']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-2">
                <label for="id_agencia" class="form-label">Agencia:</label>
                <select name="id_agencia" id="id_agencia" class="form-select" required>
                    <option value="">Seleccione</option>
                    <?php foreach ($agencias as $agencia): ?>
                        <option value="<?php echo $agencia['id_agencia']; ?>" <?php echo $agencia['id_agencia'] == $reserva['id_agencia'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($agencia['nombreAgencia']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="col-md-1">
                <label for="numero_pasajeros" class="form-label">Nº Pasajeros:</label>
                <input type="number" name="numero_pasajeros" id="numero_pasajeros" class="form-control" value="<?php echo htmlspecialchars($reserva['numero_pasajeros']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="firma" class="form-label">Firma:</label>
                <input type="text" name="firma" id="firma" class="form-control" value="<?php echo htmlspecialchars($reserva['firma']); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="observaciones" class="form-label">Observaciones:</label>
                <textarea name="observaciones" id="observaciones" class="form-control"><?php echo htmlspecialchars($reserva['observaciones'] ?? ''); ?></textarea>
            </div>
            <div class="col-md-1">
                <label for="adelanto" class="form-label">Adelanto:</label>
                <input type="number" step="0.01" name="adelanto" id="adelanto" class="form-control" value="<?php echo htmlspecialchars($reserva['adelanto'] ?? ''); ?>" required>
            </div>
            <div class="col-md-2">
                <label for="metodo_pago" class="form-label">Método de Pago:</label>
                <select name="metodo_pago" id="metodo_pago" class="form-select" required>
                    <option value="">Seleccione</option>
                    <option value="Efectivo" <?php echo ($reserva['metodo_pago'] == 'Efectivo') ? 'selected' : ''; ?>>Efectivo</option>
                    <option value="Tarjeta" <?php echo ($reserva['metodo_pago'] == 'Tarjeta') ? 'selected' : ''; ?>>Tarjeta</option>
                    <option value="Transferencia" <?php echo ($reserva['metodo_pago'] == 'Transferencia') ? 'selected' : ''; ?>>Transferencia</option>
                </select>
            </div>
            <div class="col-md-2">
                <label for="estado" class="form-label">Estado:</label>
                <select name="estado" id="estado" class="form-select" required>
                    <option value="sin pagar" <?php echo ($reserva['estado'] == 'sin pagar') ? 'selected' : ''; ?>>Sin Pagar</option>
                    <option value="pagado" <?php echo ($reserva['estado'] == 'pagado') ? 'selected' : ''; ?>>Pagado</option>
                </select>
            </div>
            <div class="col-md-1 align-self-end">
                <button type="submit" class="btn btn-primary btn-sm">Actualizar</button>
            </div>
        </form>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>