<?php
// Incluir la utilidad de autenticación
require_once '../../config/auth.php';
requireLogin();

// Configuración de depuración (mover a config.php en producción)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Incluir dependencias
require_once '../../config/config.php';
require_once '../../controllers/ReservaController.php';

// Instancia del controlador
$controller = new ReservaController($pdo);

// Parámetros de filtro sanitizados
$fechaInicio = filter_input(INPUT_GET, 'fecha_inicio', FILTER_SANITIZE_STRING);
$fechaFin = filter_input(INPUT_GET, 'fecha_fin', FILTER_SANITIZE_STRING);
$idGuiaFiltro = filter_input(INPUT_GET, 'id_guia', FILTER_VALIDATE_INT) ?: null;
$idAgenciaFiltro = filter_input(INPUT_GET, 'id_agencia', FILTER_VALIDATE_INT) ?: null;

// Obtener datos con filtros
$data = $controller->listarReservasConRelaciones($fechaInicio, $fechaFin, $idGuiaFiltro, $idAgenciaFiltro);
$reservas = $data['reservas'];
$guias = $data['guias'];
$agencias = $data['agencias'];

// Constantes
define('NO_DATA_MESSAGE', 'No hay reservas registradas.');
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Lista de Reservas</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f7fa;
            font-family: 'Poppins', sans-serif;
            color: #333;
        }
        .content {
            max-width: 1300px;
            margin: 0 auto;
            padding: 30px;
        }
        .card {
            background: #fff;
            border: none;
            border-radius: 12px;
            box-shadow: 0 6px 12px rgba(0, 0, 0, 0.1);
            padding: 25px;
        }
        h1 {
            font-size: 1.8rem;
            font-weight: 600;
            color: #1a73e8;
        }
        .btn-primary {
            background-color: #1a73e8;
            border-color: #1a73e8;
            border-radius: 8px;
            transition: background-color 0.3s ease;
        }
        .btn-primary:hover {
            background-color: #1557b0;
            border-color: #1557b0;
        }
        .btn-secondary {
            border-radius: 8px;
            transition: background-color 0.3s ease;
        }
        .btn-warning {
            background-color: #fbbc05;
            border-color: #fbbc05;
            color: #333;
            border-radius: 6px;
        }
        .btn-warning:hover {
            background-color: #e0a800;
            border-color: #e0a800;
        }
        .btn-danger {
            background-color: #ea4335;
            border-color: #ea4335;
            border-radius: 6px;
        }
        .btn-danger:hover {
            background-color: #c5221f;
            border-color: #c5221f;
        }
        .btn-sm {
            font-size: 0.85rem;
            padding: 0.3rem 0.9rem;
        }
        .filter-form .form-control,
        .filter-form .form-select {
            font-size: 0.9rem;
            border-radius: 8px;
            border: 1px solid #ced4da;
            box-shadow: inset 0 1px 3px rgba(0, 0, 0, 0.05);
        }
        .filter-form .form-label {
            font-size: 0.9rem;
            font-weight: 500;
            color: #555;
        }
        .table {
            font-size: 0.9rem;
            border-radius: 10px;
            overflow: hidden;
            background: #fff;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
        }
        .table th {
            background-color: #1a73e8;
            color: #fff;
            font-weight: 500;
            padding: 12px;
            text-align: center;
        }
        .table td {
            padding: 12px;
            vertical-align: middle;
            text-align: center;
        }
        .table-hover tbody tr:hover {
            background-color: #f8f9fa;
        }
        .badge {
            font-size: 0.8rem;
            padding: 0.4em 0.8em;
            border-radius: 12px;
        }
        .bg-success {
            background-color: #34c759 !important;
        }
        .bg-warning {
            background-color: #fb8c00 !important;
        }
        footer {
            text-align: center;
            padding: 15px 0;
            background-color: #fff;
            box-shadow: 0 -2px 8px rgba(0, 0, 0, 0.05);
            position: fixed;
            bottom: 0;
            width: 100%;
            color: #666;
        }
        @media (max-width: 768px) {
            .filter-form .col-md-2 {
                margin-bottom: 15px;
            }
            .content {
                padding: 15px;
            }
            .table td, .table th {
                font-size: 0.85rem;
            }
        }
    </style>
</head>
<body>
    <?php include '../templates/header.php'; ?>

    <div class="content">
        <div class="card">
            <h1 class="mb-4">Lista de Reservas</h1>

            <!-- Enlace para nueva reserva -->
            <a href="<?= BASE_URL ?>reserva/reservacreate.php" class="btn btn-primary btn-sm mb-4">Nueva Reserva</a>

            <!-- Formulario de filtro -->
            <form method="GET" class="filter-form row g-3 mb-4">
                <div class="col-md-2">
                    <label for="fecha_inicio" class="form-label">Fecha Inicio:</label>
                    <input type="date" name="fecha_inicio" id="fecha_inicio" class="form-control" value="<?= htmlspecialchars($fechaInicio ?? '') ?>">
                </div>
                <div class="col-md-2">
                    <label for="fecha_fin" class="form-label">Fecha Fin:</label>
                    <input type="date" name="fecha_fin" id="fecha_fin" class="form-control" value="<?= htmlspecialchars($fechaFin ?? '') ?>">
                </div>
                <div class="col-md-2">
                    <label for="id_guia" class="form-label">Guía:</label>
                    <select name="id_guia" id="id_guia" class="form-select">
                        <option value="">Todos</option>
                        <?php foreach ($guias as $guia): ?>
                            <option value="<?= $guia['id_guia'] ?>" <?= $idGuiaFiltro == $guia['id_guia'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($guia['nombreGuia']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label for="id_agencia" class="form-label">Agencia:</label>
                    <select name="id_agencia" id="id_agencia" class="form-select">
                        <option value="">Todas</option>
                        <?php foreach ($agencias as $agencia): ?>
                            <option value="<?= $agencia['id_agencia'] ?>" <?= $idAgenciaFiltro == $agencia['id_agencia'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($agencia['nombreAgencia']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2 d-flex align-items-end">
                    <button type="submit" class="btn btn-primary btn-sm me-2">Filtrar</button>
                    <a href="<?= BASE_URL ?>reserva/reservalist.php" class="btn btn-secondary btn-sm">Limpiar</a>
                </div>
            </form>

            <!-- Tabla de reservas -->
            <div class="table-responsive">
                <table class="table table-bordered table-hover">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Fecha (Mes y Año)</th>
                            <th>Guía</th>
                            <th>Agencia (Precio)</th>
                            <th>Nº Pasajeros</th>
                            <th>Firma</th>
                            <th>Observaciones</th>
                            <th>Adelanto</th>
                            <th>Método de Pago</th>
                            <th>Totalidad</th>
                            <th>Estado</th>
                            <th>Acciones</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($reservas)): ?>
                            <tr><td colspan="12" class="text-center"><?= NO_DATA_MESSAGE ?></td></tr>
                        <?php else: ?>
                            <?php foreach ($reservas as $reserva): ?>
                                <tr>
                                    <td><?= htmlspecialchars($reserva['id_reservaciongeneral']) ?></td>
                                    <td><?= htmlspecialchars($reserva['fecha_mes_y_año']) ?></td>
                                    <td><?= htmlspecialchars($reserva['nombreGuia']) ?></td>
                                    <td>
                                        <?= htmlspecialchars($reserva['nombreAgencia']) ?>
                                        (<?= htmlspecialchars($reserva['precio_agencia'] ?? 'N/A') ?>)
                                    </td>
                                    <td><?= htmlspecialchars($reserva['numero_pasajeros']) ?></td>
                                    <td><?= htmlspecialchars($reserva['firma']) ?></td>
                                    <td><?= htmlspecialchars($reserva['observaciones'] ?? 'N/A') ?></td>
                                    <td><?= htmlspecialchars($reserva['adelanto'] ?? 'N/A') ?></td>
                                    <td><?= htmlspecialchars($reserva['metodo_pago'] ?? 'N/A') ?></td>
                                    <td><?= htmlspecialchars($reserva['totalidad'] ?? 'N/A') ?></td>
                                    <td>
                                        <span class="badge <?= $reserva['estado'] === 'Confirmado' ? 'bg-success' : 'bg-warning' ?>">
                                            <?= htmlspecialchars($reserva['estado']) ?>
                                        </span>
                                    </td>
                                    <td>
                                        <a href="<?= BASE_URL ?>reserva/reservaedit.php?id=<?= $reserva['id_reservaciongeneral'] ?>" class="btn btn-warning btn-sm">Actualizar</a>
                                        <form method="POST" action="<?= BASE_URL ?>reserva/reservacreate.php" style="display:inline;">
                                            <input type="hidden" name="eliminar_reserva" value="1">
                                            <input type="hidden" name="id_reservaciongeneral" value="<?= $reserva['id_reservaciongeneral'] ?>">
                                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('¿Estás seguro de eliminar esta reserva?')">Eliminar</button>
                                        </form>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <?php include '../templates/footer.php'; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Validación simple de fechas
        document.querySelector('form').addEventListener('submit', function(e) {
            const fechaInicio = document.getElementById('fecha_inicio').value;
            const fechaFin = document.getElementById('fecha_fin').value;
            if (fechaInicio && fechaFin && new Date(fechaInicio) > new Date(fechaFin)) {
                e.preventDefault();
                alert('La fecha de inicio no puede ser mayor que la fecha de fin.');
            }
        });
    </script>
</body>
</html>